"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waCommon.WACommon_pb2
import waE2E.WAWebProtobufsE2E_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class WebMessageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BizPrivacyStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BizPrivacyStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WebMessageInfo._BizPrivacyStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        E2EE: WebMessageInfo._BizPrivacyStatus.ValueType  # 0
        FB: WebMessageInfo._BizPrivacyStatus.ValueType  # 2
        BSP: WebMessageInfo._BizPrivacyStatus.ValueType  # 1
        BSP_AND_FB: WebMessageInfo._BizPrivacyStatus.ValueType  # 3

    class BizPrivacyStatus(_BizPrivacyStatus, metaclass=_BizPrivacyStatusEnumTypeWrapper): ...
    E2EE: WebMessageInfo.BizPrivacyStatus.ValueType  # 0
    FB: WebMessageInfo.BizPrivacyStatus.ValueType  # 2
    BSP: WebMessageInfo.BizPrivacyStatus.ValueType  # 1
    BSP_AND_FB: WebMessageInfo.BizPrivacyStatus.ValueType  # 3

    class _StubType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StubTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WebMessageInfo._StubType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: WebMessageInfo._StubType.ValueType  # 0
        REVOKE: WebMessageInfo._StubType.ValueType  # 1
        CIPHERTEXT: WebMessageInfo._StubType.ValueType  # 2
        FUTUREPROOF: WebMessageInfo._StubType.ValueType  # 3
        NON_VERIFIED_TRANSITION: WebMessageInfo._StubType.ValueType  # 4
        UNVERIFIED_TRANSITION: WebMessageInfo._StubType.ValueType  # 5
        VERIFIED_TRANSITION: WebMessageInfo._StubType.ValueType  # 6
        VERIFIED_LOW_UNKNOWN: WebMessageInfo._StubType.ValueType  # 7
        VERIFIED_HIGH: WebMessageInfo._StubType.ValueType  # 8
        VERIFIED_INITIAL_UNKNOWN: WebMessageInfo._StubType.ValueType  # 9
        VERIFIED_INITIAL_LOW: WebMessageInfo._StubType.ValueType  # 10
        VERIFIED_INITIAL_HIGH: WebMessageInfo._StubType.ValueType  # 11
        VERIFIED_TRANSITION_ANY_TO_NONE: WebMessageInfo._StubType.ValueType  # 12
        VERIFIED_TRANSITION_ANY_TO_HIGH: WebMessageInfo._StubType.ValueType  # 13
        VERIFIED_TRANSITION_HIGH_TO_LOW: WebMessageInfo._StubType.ValueType  # 14
        VERIFIED_TRANSITION_HIGH_TO_UNKNOWN: WebMessageInfo._StubType.ValueType  # 15
        VERIFIED_TRANSITION_UNKNOWN_TO_LOW: WebMessageInfo._StubType.ValueType  # 16
        VERIFIED_TRANSITION_LOW_TO_UNKNOWN: WebMessageInfo._StubType.ValueType  # 17
        VERIFIED_TRANSITION_NONE_TO_LOW: WebMessageInfo._StubType.ValueType  # 18
        VERIFIED_TRANSITION_NONE_TO_UNKNOWN: WebMessageInfo._StubType.ValueType  # 19
        GROUP_CREATE: WebMessageInfo._StubType.ValueType  # 20
        GROUP_CHANGE_SUBJECT: WebMessageInfo._StubType.ValueType  # 21
        GROUP_CHANGE_ICON: WebMessageInfo._StubType.ValueType  # 22
        GROUP_CHANGE_INVITE_LINK: WebMessageInfo._StubType.ValueType  # 23
        GROUP_CHANGE_DESCRIPTION: WebMessageInfo._StubType.ValueType  # 24
        GROUP_CHANGE_RESTRICT: WebMessageInfo._StubType.ValueType  # 25
        GROUP_CHANGE_ANNOUNCE: WebMessageInfo._StubType.ValueType  # 26
        GROUP_PARTICIPANT_ADD: WebMessageInfo._StubType.ValueType  # 27
        GROUP_PARTICIPANT_REMOVE: WebMessageInfo._StubType.ValueType  # 28
        GROUP_PARTICIPANT_PROMOTE: WebMessageInfo._StubType.ValueType  # 29
        GROUP_PARTICIPANT_DEMOTE: WebMessageInfo._StubType.ValueType  # 30
        GROUP_PARTICIPANT_INVITE: WebMessageInfo._StubType.ValueType  # 31
        GROUP_PARTICIPANT_LEAVE: WebMessageInfo._StubType.ValueType  # 32
        GROUP_PARTICIPANT_CHANGE_NUMBER: WebMessageInfo._StubType.ValueType  # 33
        BROADCAST_CREATE: WebMessageInfo._StubType.ValueType  # 34
        BROADCAST_ADD: WebMessageInfo._StubType.ValueType  # 35
        BROADCAST_REMOVE: WebMessageInfo._StubType.ValueType  # 36
        GENERIC_NOTIFICATION: WebMessageInfo._StubType.ValueType  # 37
        E2E_IDENTITY_CHANGED: WebMessageInfo._StubType.ValueType  # 38
        E2E_ENCRYPTED: WebMessageInfo._StubType.ValueType  # 39
        CALL_MISSED_VOICE: WebMessageInfo._StubType.ValueType  # 40
        CALL_MISSED_VIDEO: WebMessageInfo._StubType.ValueType  # 41
        INDIVIDUAL_CHANGE_NUMBER: WebMessageInfo._StubType.ValueType  # 42
        GROUP_DELETE: WebMessageInfo._StubType.ValueType  # 43
        GROUP_ANNOUNCE_MODE_MESSAGE_BOUNCE: WebMessageInfo._StubType.ValueType  # 44
        CALL_MISSED_GROUP_VOICE: WebMessageInfo._StubType.ValueType  # 45
        CALL_MISSED_GROUP_VIDEO: WebMessageInfo._StubType.ValueType  # 46
        PAYMENT_CIPHERTEXT: WebMessageInfo._StubType.ValueType  # 47
        PAYMENT_FUTUREPROOF: WebMessageInfo._StubType.ValueType  # 48
        PAYMENT_TRANSACTION_STATUS_UPDATE_FAILED: WebMessageInfo._StubType.ValueType  # 49
        PAYMENT_TRANSACTION_STATUS_UPDATE_REFUNDED: WebMessageInfo._StubType.ValueType  # 50
        PAYMENT_TRANSACTION_STATUS_UPDATE_REFUND_FAILED: WebMessageInfo._StubType.ValueType  # 51
        PAYMENT_TRANSACTION_STATUS_RECEIVER_PENDING_SETUP: WebMessageInfo._StubType.ValueType  # 52
        PAYMENT_TRANSACTION_STATUS_RECEIVER_SUCCESS_AFTER_HICCUP: WebMessageInfo._StubType.ValueType  # 53
        PAYMENT_ACTION_ACCOUNT_SETUP_REMINDER: WebMessageInfo._StubType.ValueType  # 54
        PAYMENT_ACTION_SEND_PAYMENT_REMINDER: WebMessageInfo._StubType.ValueType  # 55
        PAYMENT_ACTION_SEND_PAYMENT_INVITATION: WebMessageInfo._StubType.ValueType  # 56
        PAYMENT_ACTION_REQUEST_DECLINED: WebMessageInfo._StubType.ValueType  # 57
        PAYMENT_ACTION_REQUEST_EXPIRED: WebMessageInfo._StubType.ValueType  # 58
        PAYMENT_ACTION_REQUEST_CANCELLED: WebMessageInfo._StubType.ValueType  # 59
        BIZ_VERIFIED_TRANSITION_TOP_TO_BOTTOM: WebMessageInfo._StubType.ValueType  # 60
        BIZ_VERIFIED_TRANSITION_BOTTOM_TO_TOP: WebMessageInfo._StubType.ValueType  # 61
        BIZ_INTRO_TOP: WebMessageInfo._StubType.ValueType  # 62
        BIZ_INTRO_BOTTOM: WebMessageInfo._StubType.ValueType  # 63
        BIZ_NAME_CHANGE: WebMessageInfo._StubType.ValueType  # 64
        BIZ_MOVE_TO_CONSUMER_APP: WebMessageInfo._StubType.ValueType  # 65
        BIZ_TWO_TIER_MIGRATION_TOP: WebMessageInfo._StubType.ValueType  # 66
        BIZ_TWO_TIER_MIGRATION_BOTTOM: WebMessageInfo._StubType.ValueType  # 67
        OVERSIZED: WebMessageInfo._StubType.ValueType  # 68
        GROUP_CHANGE_NO_FREQUENTLY_FORWARDED: WebMessageInfo._StubType.ValueType  # 69
        GROUP_V4_ADD_INVITE_SENT: WebMessageInfo._StubType.ValueType  # 70
        GROUP_PARTICIPANT_ADD_REQUEST_JOIN: WebMessageInfo._StubType.ValueType  # 71
        CHANGE_EPHEMERAL_SETTING: WebMessageInfo._StubType.ValueType  # 72
        E2E_DEVICE_CHANGED: WebMessageInfo._StubType.ValueType  # 73
        VIEWED_ONCE: WebMessageInfo._StubType.ValueType  # 74
        E2E_ENCRYPTED_NOW: WebMessageInfo._StubType.ValueType  # 75
        BLUE_MSG_BSP_FB_TO_BSP_PREMISE: WebMessageInfo._StubType.ValueType  # 76
        BLUE_MSG_BSP_FB_TO_SELF_FB: WebMessageInfo._StubType.ValueType  # 77
        BLUE_MSG_BSP_FB_TO_SELF_PREMISE: WebMessageInfo._StubType.ValueType  # 78
        BLUE_MSG_BSP_FB_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 79
        BLUE_MSG_BSP_FB_UNVERIFIED_TO_SELF_PREMISE_VERIFIED: WebMessageInfo._StubType.ValueType  # 80
        BLUE_MSG_BSP_FB_VERIFIED: WebMessageInfo._StubType.ValueType  # 81
        BLUE_MSG_BSP_FB_VERIFIED_TO_SELF_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 82
        BLUE_MSG_BSP_PREMISE_TO_SELF_PREMISE: WebMessageInfo._StubType.ValueType  # 83
        BLUE_MSG_BSP_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 84
        BLUE_MSG_BSP_PREMISE_UNVERIFIED_TO_SELF_PREMISE_VERIFIED: WebMessageInfo._StubType.ValueType  # 85
        BLUE_MSG_BSP_PREMISE_VERIFIED: WebMessageInfo._StubType.ValueType  # 86
        BLUE_MSG_BSP_PREMISE_VERIFIED_TO_SELF_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 87
        BLUE_MSG_CONSUMER_TO_BSP_FB_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 88
        BLUE_MSG_CONSUMER_TO_BSP_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 89
        BLUE_MSG_CONSUMER_TO_SELF_FB_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 90
        BLUE_MSG_CONSUMER_TO_SELF_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 91
        BLUE_MSG_SELF_FB_TO_BSP_PREMISE: WebMessageInfo._StubType.ValueType  # 92
        BLUE_MSG_SELF_FB_TO_SELF_PREMISE: WebMessageInfo._StubType.ValueType  # 93
        BLUE_MSG_SELF_FB_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 94
        BLUE_MSG_SELF_FB_UNVERIFIED_TO_SELF_PREMISE_VERIFIED: WebMessageInfo._StubType.ValueType  # 95
        BLUE_MSG_SELF_FB_VERIFIED: WebMessageInfo._StubType.ValueType  # 96
        BLUE_MSG_SELF_FB_VERIFIED_TO_SELF_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 97
        BLUE_MSG_SELF_PREMISE_TO_BSP_PREMISE: WebMessageInfo._StubType.ValueType  # 98
        BLUE_MSG_SELF_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 99
        BLUE_MSG_SELF_PREMISE_VERIFIED: WebMessageInfo._StubType.ValueType  # 100
        BLUE_MSG_TO_BSP_FB: WebMessageInfo._StubType.ValueType  # 101
        BLUE_MSG_TO_CONSUMER: WebMessageInfo._StubType.ValueType  # 102
        BLUE_MSG_TO_SELF_FB: WebMessageInfo._StubType.ValueType  # 103
        BLUE_MSG_UNVERIFIED_TO_BSP_FB_VERIFIED: WebMessageInfo._StubType.ValueType  # 104
        BLUE_MSG_UNVERIFIED_TO_BSP_PREMISE_VERIFIED: WebMessageInfo._StubType.ValueType  # 105
        BLUE_MSG_UNVERIFIED_TO_SELF_FB_VERIFIED: WebMessageInfo._StubType.ValueType  # 106
        BLUE_MSG_UNVERIFIED_TO_VERIFIED: WebMessageInfo._StubType.ValueType  # 107
        BLUE_MSG_VERIFIED_TO_BSP_FB_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 108
        BLUE_MSG_VERIFIED_TO_BSP_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 109
        BLUE_MSG_VERIFIED_TO_SELF_FB_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 110
        BLUE_MSG_VERIFIED_TO_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 111
        BLUE_MSG_BSP_FB_UNVERIFIED_TO_BSP_PREMISE_VERIFIED: WebMessageInfo._StubType.ValueType  # 112
        BLUE_MSG_BSP_FB_UNVERIFIED_TO_SELF_FB_VERIFIED: WebMessageInfo._StubType.ValueType  # 113
        BLUE_MSG_BSP_FB_VERIFIED_TO_BSP_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 114
        BLUE_MSG_BSP_FB_VERIFIED_TO_SELF_FB_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 115
        BLUE_MSG_SELF_FB_UNVERIFIED_TO_BSP_PREMISE_VERIFIED: WebMessageInfo._StubType.ValueType  # 116
        BLUE_MSG_SELF_FB_VERIFIED_TO_BSP_PREMISE_UNVERIFIED: WebMessageInfo._StubType.ValueType  # 117
        E2E_IDENTITY_UNAVAILABLE: WebMessageInfo._StubType.ValueType  # 118
        GROUP_CREATING: WebMessageInfo._StubType.ValueType  # 119
        GROUP_CREATE_FAILED: WebMessageInfo._StubType.ValueType  # 120
        GROUP_BOUNCED: WebMessageInfo._StubType.ValueType  # 121
        BLOCK_CONTACT: WebMessageInfo._StubType.ValueType  # 122
        EPHEMERAL_SETTING_NOT_APPLIED: WebMessageInfo._StubType.ValueType  # 123
        SYNC_FAILED: WebMessageInfo._StubType.ValueType  # 124
        SYNCING: WebMessageInfo._StubType.ValueType  # 125
        BIZ_PRIVACY_MODE_INIT_FB: WebMessageInfo._StubType.ValueType  # 126
        BIZ_PRIVACY_MODE_INIT_BSP: WebMessageInfo._StubType.ValueType  # 127
        BIZ_PRIVACY_MODE_TO_FB: WebMessageInfo._StubType.ValueType  # 128
        BIZ_PRIVACY_MODE_TO_BSP: WebMessageInfo._StubType.ValueType  # 129
        DISAPPEARING_MODE: WebMessageInfo._StubType.ValueType  # 130
        E2E_DEVICE_FETCH_FAILED: WebMessageInfo._StubType.ValueType  # 131
        ADMIN_REVOKE: WebMessageInfo._StubType.ValueType  # 132
        GROUP_INVITE_LINK_GROWTH_LOCKED: WebMessageInfo._StubType.ValueType  # 133
        COMMUNITY_LINK_PARENT_GROUP: WebMessageInfo._StubType.ValueType  # 134
        COMMUNITY_LINK_SIBLING_GROUP: WebMessageInfo._StubType.ValueType  # 135
        COMMUNITY_LINK_SUB_GROUP: WebMessageInfo._StubType.ValueType  # 136
        COMMUNITY_UNLINK_PARENT_GROUP: WebMessageInfo._StubType.ValueType  # 137
        COMMUNITY_UNLINK_SIBLING_GROUP: WebMessageInfo._StubType.ValueType  # 138
        COMMUNITY_UNLINK_SUB_GROUP: WebMessageInfo._StubType.ValueType  # 139
        GROUP_PARTICIPANT_ACCEPT: WebMessageInfo._StubType.ValueType  # 140
        GROUP_PARTICIPANT_LINKED_GROUP_JOIN: WebMessageInfo._StubType.ValueType  # 141
        COMMUNITY_CREATE: WebMessageInfo._StubType.ValueType  # 142
        EPHEMERAL_KEEP_IN_CHAT: WebMessageInfo._StubType.ValueType  # 143
        GROUP_MEMBERSHIP_JOIN_APPROVAL_REQUEST: WebMessageInfo._StubType.ValueType  # 144
        GROUP_MEMBERSHIP_JOIN_APPROVAL_MODE: WebMessageInfo._StubType.ValueType  # 145
        INTEGRITY_UNLINK_PARENT_GROUP: WebMessageInfo._StubType.ValueType  # 146
        COMMUNITY_PARTICIPANT_PROMOTE: WebMessageInfo._StubType.ValueType  # 147
        COMMUNITY_PARTICIPANT_DEMOTE: WebMessageInfo._StubType.ValueType  # 148
        COMMUNITY_PARENT_GROUP_DELETED: WebMessageInfo._StubType.ValueType  # 149
        COMMUNITY_LINK_PARENT_GROUP_MEMBERSHIP_APPROVAL: WebMessageInfo._StubType.ValueType  # 150
        GROUP_PARTICIPANT_JOINED_GROUP_AND_PARENT_GROUP: WebMessageInfo._StubType.ValueType  # 151
        MASKED_THREAD_CREATED: WebMessageInfo._StubType.ValueType  # 152
        MASKED_THREAD_UNMASKED: WebMessageInfo._StubType.ValueType  # 153
        BIZ_CHAT_ASSIGNMENT: WebMessageInfo._StubType.ValueType  # 154
        CHAT_PSA: WebMessageInfo._StubType.ValueType  # 155
        CHAT_POLL_CREATION_MESSAGE: WebMessageInfo._StubType.ValueType  # 156
        CAG_MASKED_THREAD_CREATED: WebMessageInfo._StubType.ValueType  # 157
        COMMUNITY_PARENT_GROUP_SUBJECT_CHANGED: WebMessageInfo._StubType.ValueType  # 158
        CAG_INVITE_AUTO_ADD: WebMessageInfo._StubType.ValueType  # 159
        BIZ_CHAT_ASSIGNMENT_UNASSIGN: WebMessageInfo._StubType.ValueType  # 160
        CAG_INVITE_AUTO_JOINED: WebMessageInfo._StubType.ValueType  # 161
        SCHEDULED_CALL_START_MESSAGE: WebMessageInfo._StubType.ValueType  # 162
        COMMUNITY_INVITE_RICH: WebMessageInfo._StubType.ValueType  # 163
        COMMUNITY_INVITE_AUTO_ADD_RICH: WebMessageInfo._StubType.ValueType  # 164
        SUB_GROUP_INVITE_RICH: WebMessageInfo._StubType.ValueType  # 165
        SUB_GROUP_PARTICIPANT_ADD_RICH: WebMessageInfo._StubType.ValueType  # 166
        COMMUNITY_LINK_PARENT_GROUP_RICH: WebMessageInfo._StubType.ValueType  # 167
        COMMUNITY_PARTICIPANT_ADD_RICH: WebMessageInfo._StubType.ValueType  # 168
        SILENCED_UNKNOWN_CALLER_AUDIO: WebMessageInfo._StubType.ValueType  # 169
        SILENCED_UNKNOWN_CALLER_VIDEO: WebMessageInfo._StubType.ValueType  # 170
        GROUP_MEMBER_ADD_MODE: WebMessageInfo._StubType.ValueType  # 171
        GROUP_MEMBERSHIP_JOIN_APPROVAL_REQUEST_NON_ADMIN_ADD: WebMessageInfo._StubType.ValueType  # 172
        COMMUNITY_CHANGE_DESCRIPTION: WebMessageInfo._StubType.ValueType  # 173
        SENDER_INVITE: WebMessageInfo._StubType.ValueType  # 174
        RECEIVER_INVITE: WebMessageInfo._StubType.ValueType  # 175
        COMMUNITY_ALLOW_MEMBER_ADDED_GROUPS: WebMessageInfo._StubType.ValueType  # 176
        PINNED_MESSAGE_IN_CHAT: WebMessageInfo._StubType.ValueType  # 177
        PAYMENT_INVITE_SETUP_INVITER: WebMessageInfo._StubType.ValueType  # 178
        PAYMENT_INVITE_SETUP_INVITEE_RECEIVE_ONLY: WebMessageInfo._StubType.ValueType  # 179
        PAYMENT_INVITE_SETUP_INVITEE_SEND_AND_RECEIVE: WebMessageInfo._StubType.ValueType  # 180
        LINKED_GROUP_CALL_START: WebMessageInfo._StubType.ValueType  # 181
        REPORT_TO_ADMIN_ENABLED_STATUS: WebMessageInfo._StubType.ValueType  # 182
        EMPTY_SUBGROUP_CREATE: WebMessageInfo._StubType.ValueType  # 183
        SCHEDULED_CALL_CANCEL: WebMessageInfo._StubType.ValueType  # 184
        SUBGROUP_ADMIN_TRIGGERED_AUTO_ADD_RICH: WebMessageInfo._StubType.ValueType  # 185
        GROUP_CHANGE_RECENT_HISTORY_SHARING: WebMessageInfo._StubType.ValueType  # 186
        PAID_MESSAGE_SERVER_CAMPAIGN_ID: WebMessageInfo._StubType.ValueType  # 187
        GENERAL_CHAT_CREATE: WebMessageInfo._StubType.ValueType  # 188
        GENERAL_CHAT_ADD: WebMessageInfo._StubType.ValueType  # 189
        GENERAL_CHAT_AUTO_ADD_DISABLED: WebMessageInfo._StubType.ValueType  # 190
        SUGGESTED_SUBGROUP_ANNOUNCE: WebMessageInfo._StubType.ValueType  # 191
        BIZ_BOT_1P_MESSAGING_ENABLED: WebMessageInfo._StubType.ValueType  # 192
        CHANGE_USERNAME: WebMessageInfo._StubType.ValueType  # 193
        BIZ_COEX_PRIVACY_INIT_SELF: WebMessageInfo._StubType.ValueType  # 194
        BIZ_COEX_PRIVACY_TRANSITION_SELF: WebMessageInfo._StubType.ValueType  # 195
        SUPPORT_AI_EDUCATION: WebMessageInfo._StubType.ValueType  # 196
        BIZ_BOT_3P_MESSAGING_ENABLED: WebMessageInfo._StubType.ValueType  # 197
        REMINDER_SETUP_MESSAGE: WebMessageInfo._StubType.ValueType  # 198
        REMINDER_SENT_MESSAGE: WebMessageInfo._StubType.ValueType  # 199
        REMINDER_CANCEL_MESSAGE: WebMessageInfo._StubType.ValueType  # 200
        BIZ_COEX_PRIVACY_INIT: WebMessageInfo._StubType.ValueType  # 201
        BIZ_COEX_PRIVACY_TRANSITION: WebMessageInfo._StubType.ValueType  # 202
        GROUP_DEACTIVATED: WebMessageInfo._StubType.ValueType  # 203
        COMMUNITY_DEACTIVATE_SIBLING_GROUP: WebMessageInfo._StubType.ValueType  # 204
        EVENT_UPDATED: WebMessageInfo._StubType.ValueType  # 205
        EVENT_CANCELED: WebMessageInfo._StubType.ValueType  # 206
        COMMUNITY_OWNER_UPDATED: WebMessageInfo._StubType.ValueType  # 207
        COMMUNITY_SUB_GROUP_VISIBILITY_HIDDEN: WebMessageInfo._StubType.ValueType  # 208
        CAPI_GROUP_NE2EE_SYSTEM_MESSAGE: WebMessageInfo._StubType.ValueType  # 209
        STATUS_MENTION: WebMessageInfo._StubType.ValueType  # 210
        USER_CONTROLS_SYSTEM_MESSAGE: WebMessageInfo._StubType.ValueType  # 211
        SUPPORT_SYSTEM_MESSAGE: WebMessageInfo._StubType.ValueType  # 212
        CHANGE_LID: WebMessageInfo._StubType.ValueType  # 213
        BIZ_CUSTOMER_3PD_DATA_SHARING_OPT_IN_MESSAGE: WebMessageInfo._StubType.ValueType  # 214
        BIZ_CUSTOMER_3PD_DATA_SHARING_OPT_OUT_MESSAGE: WebMessageInfo._StubType.ValueType  # 215
        CHANGE_LIMIT_SHARING: WebMessageInfo._StubType.ValueType  # 216
        GROUP_MEMBER_LINK_MODE: WebMessageInfo._StubType.ValueType  # 217

    class StubType(_StubType, metaclass=_StubTypeEnumTypeWrapper): ...
    UNKNOWN: WebMessageInfo.StubType.ValueType  # 0
    REVOKE: WebMessageInfo.StubType.ValueType  # 1
    CIPHERTEXT: WebMessageInfo.StubType.ValueType  # 2
    FUTUREPROOF: WebMessageInfo.StubType.ValueType  # 3
    NON_VERIFIED_TRANSITION: WebMessageInfo.StubType.ValueType  # 4
    UNVERIFIED_TRANSITION: WebMessageInfo.StubType.ValueType  # 5
    VERIFIED_TRANSITION: WebMessageInfo.StubType.ValueType  # 6
    VERIFIED_LOW_UNKNOWN: WebMessageInfo.StubType.ValueType  # 7
    VERIFIED_HIGH: WebMessageInfo.StubType.ValueType  # 8
    VERIFIED_INITIAL_UNKNOWN: WebMessageInfo.StubType.ValueType  # 9
    VERIFIED_INITIAL_LOW: WebMessageInfo.StubType.ValueType  # 10
    VERIFIED_INITIAL_HIGH: WebMessageInfo.StubType.ValueType  # 11
    VERIFIED_TRANSITION_ANY_TO_NONE: WebMessageInfo.StubType.ValueType  # 12
    VERIFIED_TRANSITION_ANY_TO_HIGH: WebMessageInfo.StubType.ValueType  # 13
    VERIFIED_TRANSITION_HIGH_TO_LOW: WebMessageInfo.StubType.ValueType  # 14
    VERIFIED_TRANSITION_HIGH_TO_UNKNOWN: WebMessageInfo.StubType.ValueType  # 15
    VERIFIED_TRANSITION_UNKNOWN_TO_LOW: WebMessageInfo.StubType.ValueType  # 16
    VERIFIED_TRANSITION_LOW_TO_UNKNOWN: WebMessageInfo.StubType.ValueType  # 17
    VERIFIED_TRANSITION_NONE_TO_LOW: WebMessageInfo.StubType.ValueType  # 18
    VERIFIED_TRANSITION_NONE_TO_UNKNOWN: WebMessageInfo.StubType.ValueType  # 19
    GROUP_CREATE: WebMessageInfo.StubType.ValueType  # 20
    GROUP_CHANGE_SUBJECT: WebMessageInfo.StubType.ValueType  # 21
    GROUP_CHANGE_ICON: WebMessageInfo.StubType.ValueType  # 22
    GROUP_CHANGE_INVITE_LINK: WebMessageInfo.StubType.ValueType  # 23
    GROUP_CHANGE_DESCRIPTION: WebMessageInfo.StubType.ValueType  # 24
    GROUP_CHANGE_RESTRICT: WebMessageInfo.StubType.ValueType  # 25
    GROUP_CHANGE_ANNOUNCE: WebMessageInfo.StubType.ValueType  # 26
    GROUP_PARTICIPANT_ADD: WebMessageInfo.StubType.ValueType  # 27
    GROUP_PARTICIPANT_REMOVE: WebMessageInfo.StubType.ValueType  # 28
    GROUP_PARTICIPANT_PROMOTE: WebMessageInfo.StubType.ValueType  # 29
    GROUP_PARTICIPANT_DEMOTE: WebMessageInfo.StubType.ValueType  # 30
    GROUP_PARTICIPANT_INVITE: WebMessageInfo.StubType.ValueType  # 31
    GROUP_PARTICIPANT_LEAVE: WebMessageInfo.StubType.ValueType  # 32
    GROUP_PARTICIPANT_CHANGE_NUMBER: WebMessageInfo.StubType.ValueType  # 33
    BROADCAST_CREATE: WebMessageInfo.StubType.ValueType  # 34
    BROADCAST_ADD: WebMessageInfo.StubType.ValueType  # 35
    BROADCAST_REMOVE: WebMessageInfo.StubType.ValueType  # 36
    GENERIC_NOTIFICATION: WebMessageInfo.StubType.ValueType  # 37
    E2E_IDENTITY_CHANGED: WebMessageInfo.StubType.ValueType  # 38
    E2E_ENCRYPTED: WebMessageInfo.StubType.ValueType  # 39
    CALL_MISSED_VOICE: WebMessageInfo.StubType.ValueType  # 40
    CALL_MISSED_VIDEO: WebMessageInfo.StubType.ValueType  # 41
    INDIVIDUAL_CHANGE_NUMBER: WebMessageInfo.StubType.ValueType  # 42
    GROUP_DELETE: WebMessageInfo.StubType.ValueType  # 43
    GROUP_ANNOUNCE_MODE_MESSAGE_BOUNCE: WebMessageInfo.StubType.ValueType  # 44
    CALL_MISSED_GROUP_VOICE: WebMessageInfo.StubType.ValueType  # 45
    CALL_MISSED_GROUP_VIDEO: WebMessageInfo.StubType.ValueType  # 46
    PAYMENT_CIPHERTEXT: WebMessageInfo.StubType.ValueType  # 47
    PAYMENT_FUTUREPROOF: WebMessageInfo.StubType.ValueType  # 48
    PAYMENT_TRANSACTION_STATUS_UPDATE_FAILED: WebMessageInfo.StubType.ValueType  # 49
    PAYMENT_TRANSACTION_STATUS_UPDATE_REFUNDED: WebMessageInfo.StubType.ValueType  # 50
    PAYMENT_TRANSACTION_STATUS_UPDATE_REFUND_FAILED: WebMessageInfo.StubType.ValueType  # 51
    PAYMENT_TRANSACTION_STATUS_RECEIVER_PENDING_SETUP: WebMessageInfo.StubType.ValueType  # 52
    PAYMENT_TRANSACTION_STATUS_RECEIVER_SUCCESS_AFTER_HICCUP: WebMessageInfo.StubType.ValueType  # 53
    PAYMENT_ACTION_ACCOUNT_SETUP_REMINDER: WebMessageInfo.StubType.ValueType  # 54
    PAYMENT_ACTION_SEND_PAYMENT_REMINDER: WebMessageInfo.StubType.ValueType  # 55
    PAYMENT_ACTION_SEND_PAYMENT_INVITATION: WebMessageInfo.StubType.ValueType  # 56
    PAYMENT_ACTION_REQUEST_DECLINED: WebMessageInfo.StubType.ValueType  # 57
    PAYMENT_ACTION_REQUEST_EXPIRED: WebMessageInfo.StubType.ValueType  # 58
    PAYMENT_ACTION_REQUEST_CANCELLED: WebMessageInfo.StubType.ValueType  # 59
    BIZ_VERIFIED_TRANSITION_TOP_TO_BOTTOM: WebMessageInfo.StubType.ValueType  # 60
    BIZ_VERIFIED_TRANSITION_BOTTOM_TO_TOP: WebMessageInfo.StubType.ValueType  # 61
    BIZ_INTRO_TOP: WebMessageInfo.StubType.ValueType  # 62
    BIZ_INTRO_BOTTOM: WebMessageInfo.StubType.ValueType  # 63
    BIZ_NAME_CHANGE: WebMessageInfo.StubType.ValueType  # 64
    BIZ_MOVE_TO_CONSUMER_APP: WebMessageInfo.StubType.ValueType  # 65
    BIZ_TWO_TIER_MIGRATION_TOP: WebMessageInfo.StubType.ValueType  # 66
    BIZ_TWO_TIER_MIGRATION_BOTTOM: WebMessageInfo.StubType.ValueType  # 67
    OVERSIZED: WebMessageInfo.StubType.ValueType  # 68
    GROUP_CHANGE_NO_FREQUENTLY_FORWARDED: WebMessageInfo.StubType.ValueType  # 69
    GROUP_V4_ADD_INVITE_SENT: WebMessageInfo.StubType.ValueType  # 70
    GROUP_PARTICIPANT_ADD_REQUEST_JOIN: WebMessageInfo.StubType.ValueType  # 71
    CHANGE_EPHEMERAL_SETTING: WebMessageInfo.StubType.ValueType  # 72
    E2E_DEVICE_CHANGED: WebMessageInfo.StubType.ValueType  # 73
    VIEWED_ONCE: WebMessageInfo.StubType.ValueType  # 74
    E2E_ENCRYPTED_NOW: WebMessageInfo.StubType.ValueType  # 75
    BLUE_MSG_BSP_FB_TO_BSP_PREMISE: WebMessageInfo.StubType.ValueType  # 76
    BLUE_MSG_BSP_FB_TO_SELF_FB: WebMessageInfo.StubType.ValueType  # 77
    BLUE_MSG_BSP_FB_TO_SELF_PREMISE: WebMessageInfo.StubType.ValueType  # 78
    BLUE_MSG_BSP_FB_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 79
    BLUE_MSG_BSP_FB_UNVERIFIED_TO_SELF_PREMISE_VERIFIED: WebMessageInfo.StubType.ValueType  # 80
    BLUE_MSG_BSP_FB_VERIFIED: WebMessageInfo.StubType.ValueType  # 81
    BLUE_MSG_BSP_FB_VERIFIED_TO_SELF_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 82
    BLUE_MSG_BSP_PREMISE_TO_SELF_PREMISE: WebMessageInfo.StubType.ValueType  # 83
    BLUE_MSG_BSP_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 84
    BLUE_MSG_BSP_PREMISE_UNVERIFIED_TO_SELF_PREMISE_VERIFIED: WebMessageInfo.StubType.ValueType  # 85
    BLUE_MSG_BSP_PREMISE_VERIFIED: WebMessageInfo.StubType.ValueType  # 86
    BLUE_MSG_BSP_PREMISE_VERIFIED_TO_SELF_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 87
    BLUE_MSG_CONSUMER_TO_BSP_FB_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 88
    BLUE_MSG_CONSUMER_TO_BSP_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 89
    BLUE_MSG_CONSUMER_TO_SELF_FB_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 90
    BLUE_MSG_CONSUMER_TO_SELF_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 91
    BLUE_MSG_SELF_FB_TO_BSP_PREMISE: WebMessageInfo.StubType.ValueType  # 92
    BLUE_MSG_SELF_FB_TO_SELF_PREMISE: WebMessageInfo.StubType.ValueType  # 93
    BLUE_MSG_SELF_FB_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 94
    BLUE_MSG_SELF_FB_UNVERIFIED_TO_SELF_PREMISE_VERIFIED: WebMessageInfo.StubType.ValueType  # 95
    BLUE_MSG_SELF_FB_VERIFIED: WebMessageInfo.StubType.ValueType  # 96
    BLUE_MSG_SELF_FB_VERIFIED_TO_SELF_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 97
    BLUE_MSG_SELF_PREMISE_TO_BSP_PREMISE: WebMessageInfo.StubType.ValueType  # 98
    BLUE_MSG_SELF_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 99
    BLUE_MSG_SELF_PREMISE_VERIFIED: WebMessageInfo.StubType.ValueType  # 100
    BLUE_MSG_TO_BSP_FB: WebMessageInfo.StubType.ValueType  # 101
    BLUE_MSG_TO_CONSUMER: WebMessageInfo.StubType.ValueType  # 102
    BLUE_MSG_TO_SELF_FB: WebMessageInfo.StubType.ValueType  # 103
    BLUE_MSG_UNVERIFIED_TO_BSP_FB_VERIFIED: WebMessageInfo.StubType.ValueType  # 104
    BLUE_MSG_UNVERIFIED_TO_BSP_PREMISE_VERIFIED: WebMessageInfo.StubType.ValueType  # 105
    BLUE_MSG_UNVERIFIED_TO_SELF_FB_VERIFIED: WebMessageInfo.StubType.ValueType  # 106
    BLUE_MSG_UNVERIFIED_TO_VERIFIED: WebMessageInfo.StubType.ValueType  # 107
    BLUE_MSG_VERIFIED_TO_BSP_FB_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 108
    BLUE_MSG_VERIFIED_TO_BSP_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 109
    BLUE_MSG_VERIFIED_TO_SELF_FB_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 110
    BLUE_MSG_VERIFIED_TO_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 111
    BLUE_MSG_BSP_FB_UNVERIFIED_TO_BSP_PREMISE_VERIFIED: WebMessageInfo.StubType.ValueType  # 112
    BLUE_MSG_BSP_FB_UNVERIFIED_TO_SELF_FB_VERIFIED: WebMessageInfo.StubType.ValueType  # 113
    BLUE_MSG_BSP_FB_VERIFIED_TO_BSP_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 114
    BLUE_MSG_BSP_FB_VERIFIED_TO_SELF_FB_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 115
    BLUE_MSG_SELF_FB_UNVERIFIED_TO_BSP_PREMISE_VERIFIED: WebMessageInfo.StubType.ValueType  # 116
    BLUE_MSG_SELF_FB_VERIFIED_TO_BSP_PREMISE_UNVERIFIED: WebMessageInfo.StubType.ValueType  # 117
    E2E_IDENTITY_UNAVAILABLE: WebMessageInfo.StubType.ValueType  # 118
    GROUP_CREATING: WebMessageInfo.StubType.ValueType  # 119
    GROUP_CREATE_FAILED: WebMessageInfo.StubType.ValueType  # 120
    GROUP_BOUNCED: WebMessageInfo.StubType.ValueType  # 121
    BLOCK_CONTACT: WebMessageInfo.StubType.ValueType  # 122
    EPHEMERAL_SETTING_NOT_APPLIED: WebMessageInfo.StubType.ValueType  # 123
    SYNC_FAILED: WebMessageInfo.StubType.ValueType  # 124
    SYNCING: WebMessageInfo.StubType.ValueType  # 125
    BIZ_PRIVACY_MODE_INIT_FB: WebMessageInfo.StubType.ValueType  # 126
    BIZ_PRIVACY_MODE_INIT_BSP: WebMessageInfo.StubType.ValueType  # 127
    BIZ_PRIVACY_MODE_TO_FB: WebMessageInfo.StubType.ValueType  # 128
    BIZ_PRIVACY_MODE_TO_BSP: WebMessageInfo.StubType.ValueType  # 129
    DISAPPEARING_MODE: WebMessageInfo.StubType.ValueType  # 130
    E2E_DEVICE_FETCH_FAILED: WebMessageInfo.StubType.ValueType  # 131
    ADMIN_REVOKE: WebMessageInfo.StubType.ValueType  # 132
    GROUP_INVITE_LINK_GROWTH_LOCKED: WebMessageInfo.StubType.ValueType  # 133
    COMMUNITY_LINK_PARENT_GROUP: WebMessageInfo.StubType.ValueType  # 134
    COMMUNITY_LINK_SIBLING_GROUP: WebMessageInfo.StubType.ValueType  # 135
    COMMUNITY_LINK_SUB_GROUP: WebMessageInfo.StubType.ValueType  # 136
    COMMUNITY_UNLINK_PARENT_GROUP: WebMessageInfo.StubType.ValueType  # 137
    COMMUNITY_UNLINK_SIBLING_GROUP: WebMessageInfo.StubType.ValueType  # 138
    COMMUNITY_UNLINK_SUB_GROUP: WebMessageInfo.StubType.ValueType  # 139
    GROUP_PARTICIPANT_ACCEPT: WebMessageInfo.StubType.ValueType  # 140
    GROUP_PARTICIPANT_LINKED_GROUP_JOIN: WebMessageInfo.StubType.ValueType  # 141
    COMMUNITY_CREATE: WebMessageInfo.StubType.ValueType  # 142
    EPHEMERAL_KEEP_IN_CHAT: WebMessageInfo.StubType.ValueType  # 143
    GROUP_MEMBERSHIP_JOIN_APPROVAL_REQUEST: WebMessageInfo.StubType.ValueType  # 144
    GROUP_MEMBERSHIP_JOIN_APPROVAL_MODE: WebMessageInfo.StubType.ValueType  # 145
    INTEGRITY_UNLINK_PARENT_GROUP: WebMessageInfo.StubType.ValueType  # 146
    COMMUNITY_PARTICIPANT_PROMOTE: WebMessageInfo.StubType.ValueType  # 147
    COMMUNITY_PARTICIPANT_DEMOTE: WebMessageInfo.StubType.ValueType  # 148
    COMMUNITY_PARENT_GROUP_DELETED: WebMessageInfo.StubType.ValueType  # 149
    COMMUNITY_LINK_PARENT_GROUP_MEMBERSHIP_APPROVAL: WebMessageInfo.StubType.ValueType  # 150
    GROUP_PARTICIPANT_JOINED_GROUP_AND_PARENT_GROUP: WebMessageInfo.StubType.ValueType  # 151
    MASKED_THREAD_CREATED: WebMessageInfo.StubType.ValueType  # 152
    MASKED_THREAD_UNMASKED: WebMessageInfo.StubType.ValueType  # 153
    BIZ_CHAT_ASSIGNMENT: WebMessageInfo.StubType.ValueType  # 154
    CHAT_PSA: WebMessageInfo.StubType.ValueType  # 155
    CHAT_POLL_CREATION_MESSAGE: WebMessageInfo.StubType.ValueType  # 156
    CAG_MASKED_THREAD_CREATED: WebMessageInfo.StubType.ValueType  # 157
    COMMUNITY_PARENT_GROUP_SUBJECT_CHANGED: WebMessageInfo.StubType.ValueType  # 158
    CAG_INVITE_AUTO_ADD: WebMessageInfo.StubType.ValueType  # 159
    BIZ_CHAT_ASSIGNMENT_UNASSIGN: WebMessageInfo.StubType.ValueType  # 160
    CAG_INVITE_AUTO_JOINED: WebMessageInfo.StubType.ValueType  # 161
    SCHEDULED_CALL_START_MESSAGE: WebMessageInfo.StubType.ValueType  # 162
    COMMUNITY_INVITE_RICH: WebMessageInfo.StubType.ValueType  # 163
    COMMUNITY_INVITE_AUTO_ADD_RICH: WebMessageInfo.StubType.ValueType  # 164
    SUB_GROUP_INVITE_RICH: WebMessageInfo.StubType.ValueType  # 165
    SUB_GROUP_PARTICIPANT_ADD_RICH: WebMessageInfo.StubType.ValueType  # 166
    COMMUNITY_LINK_PARENT_GROUP_RICH: WebMessageInfo.StubType.ValueType  # 167
    COMMUNITY_PARTICIPANT_ADD_RICH: WebMessageInfo.StubType.ValueType  # 168
    SILENCED_UNKNOWN_CALLER_AUDIO: WebMessageInfo.StubType.ValueType  # 169
    SILENCED_UNKNOWN_CALLER_VIDEO: WebMessageInfo.StubType.ValueType  # 170
    GROUP_MEMBER_ADD_MODE: WebMessageInfo.StubType.ValueType  # 171
    GROUP_MEMBERSHIP_JOIN_APPROVAL_REQUEST_NON_ADMIN_ADD: WebMessageInfo.StubType.ValueType  # 172
    COMMUNITY_CHANGE_DESCRIPTION: WebMessageInfo.StubType.ValueType  # 173
    SENDER_INVITE: WebMessageInfo.StubType.ValueType  # 174
    RECEIVER_INVITE: WebMessageInfo.StubType.ValueType  # 175
    COMMUNITY_ALLOW_MEMBER_ADDED_GROUPS: WebMessageInfo.StubType.ValueType  # 176
    PINNED_MESSAGE_IN_CHAT: WebMessageInfo.StubType.ValueType  # 177
    PAYMENT_INVITE_SETUP_INVITER: WebMessageInfo.StubType.ValueType  # 178
    PAYMENT_INVITE_SETUP_INVITEE_RECEIVE_ONLY: WebMessageInfo.StubType.ValueType  # 179
    PAYMENT_INVITE_SETUP_INVITEE_SEND_AND_RECEIVE: WebMessageInfo.StubType.ValueType  # 180
    LINKED_GROUP_CALL_START: WebMessageInfo.StubType.ValueType  # 181
    REPORT_TO_ADMIN_ENABLED_STATUS: WebMessageInfo.StubType.ValueType  # 182
    EMPTY_SUBGROUP_CREATE: WebMessageInfo.StubType.ValueType  # 183
    SCHEDULED_CALL_CANCEL: WebMessageInfo.StubType.ValueType  # 184
    SUBGROUP_ADMIN_TRIGGERED_AUTO_ADD_RICH: WebMessageInfo.StubType.ValueType  # 185
    GROUP_CHANGE_RECENT_HISTORY_SHARING: WebMessageInfo.StubType.ValueType  # 186
    PAID_MESSAGE_SERVER_CAMPAIGN_ID: WebMessageInfo.StubType.ValueType  # 187
    GENERAL_CHAT_CREATE: WebMessageInfo.StubType.ValueType  # 188
    GENERAL_CHAT_ADD: WebMessageInfo.StubType.ValueType  # 189
    GENERAL_CHAT_AUTO_ADD_DISABLED: WebMessageInfo.StubType.ValueType  # 190
    SUGGESTED_SUBGROUP_ANNOUNCE: WebMessageInfo.StubType.ValueType  # 191
    BIZ_BOT_1P_MESSAGING_ENABLED: WebMessageInfo.StubType.ValueType  # 192
    CHANGE_USERNAME: WebMessageInfo.StubType.ValueType  # 193
    BIZ_COEX_PRIVACY_INIT_SELF: WebMessageInfo.StubType.ValueType  # 194
    BIZ_COEX_PRIVACY_TRANSITION_SELF: WebMessageInfo.StubType.ValueType  # 195
    SUPPORT_AI_EDUCATION: WebMessageInfo.StubType.ValueType  # 196
    BIZ_BOT_3P_MESSAGING_ENABLED: WebMessageInfo.StubType.ValueType  # 197
    REMINDER_SETUP_MESSAGE: WebMessageInfo.StubType.ValueType  # 198
    REMINDER_SENT_MESSAGE: WebMessageInfo.StubType.ValueType  # 199
    REMINDER_CANCEL_MESSAGE: WebMessageInfo.StubType.ValueType  # 200
    BIZ_COEX_PRIVACY_INIT: WebMessageInfo.StubType.ValueType  # 201
    BIZ_COEX_PRIVACY_TRANSITION: WebMessageInfo.StubType.ValueType  # 202
    GROUP_DEACTIVATED: WebMessageInfo.StubType.ValueType  # 203
    COMMUNITY_DEACTIVATE_SIBLING_GROUP: WebMessageInfo.StubType.ValueType  # 204
    EVENT_UPDATED: WebMessageInfo.StubType.ValueType  # 205
    EVENT_CANCELED: WebMessageInfo.StubType.ValueType  # 206
    COMMUNITY_OWNER_UPDATED: WebMessageInfo.StubType.ValueType  # 207
    COMMUNITY_SUB_GROUP_VISIBILITY_HIDDEN: WebMessageInfo.StubType.ValueType  # 208
    CAPI_GROUP_NE2EE_SYSTEM_MESSAGE: WebMessageInfo.StubType.ValueType  # 209
    STATUS_MENTION: WebMessageInfo.StubType.ValueType  # 210
    USER_CONTROLS_SYSTEM_MESSAGE: WebMessageInfo.StubType.ValueType  # 211
    SUPPORT_SYSTEM_MESSAGE: WebMessageInfo.StubType.ValueType  # 212
    CHANGE_LID: WebMessageInfo.StubType.ValueType  # 213
    BIZ_CUSTOMER_3PD_DATA_SHARING_OPT_IN_MESSAGE: WebMessageInfo.StubType.ValueType  # 214
    BIZ_CUSTOMER_3PD_DATA_SHARING_OPT_OUT_MESSAGE: WebMessageInfo.StubType.ValueType  # 215
    CHANGE_LIMIT_SHARING: WebMessageInfo.StubType.ValueType  # 216
    GROUP_MEMBER_LINK_MODE: WebMessageInfo.StubType.ValueType  # 217

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WebMessageInfo._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ERROR: WebMessageInfo._Status.ValueType  # 0
        PENDING: WebMessageInfo._Status.ValueType  # 1
        SERVER_ACK: WebMessageInfo._Status.ValueType  # 2
        DELIVERY_ACK: WebMessageInfo._Status.ValueType  # 3
        READ: WebMessageInfo._Status.ValueType  # 4
        PLAYED: WebMessageInfo._Status.ValueType  # 5

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    ERROR: WebMessageInfo.Status.ValueType  # 0
    PENDING: WebMessageInfo.Status.ValueType  # 1
    SERVER_ACK: WebMessageInfo.Status.ValueType  # 2
    DELIVERY_ACK: WebMessageInfo.Status.ValueType  # 3
    READ: WebMessageInfo.Status.ValueType  # 4
    PLAYED: WebMessageInfo.Status.ValueType  # 5

    KEY_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    MESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PARTICIPANT_FIELD_NUMBER: builtins.int
    MESSAGEC2STIMESTAMP_FIELD_NUMBER: builtins.int
    IGNORE_FIELD_NUMBER: builtins.int
    STARRED_FIELD_NUMBER: builtins.int
    BROADCAST_FIELD_NUMBER: builtins.int
    PUSHNAME_FIELD_NUMBER: builtins.int
    MEDIACIPHERTEXTSHA256_FIELD_NUMBER: builtins.int
    MULTICAST_FIELD_NUMBER: builtins.int
    URLTEXT_FIELD_NUMBER: builtins.int
    URLNUMBER_FIELD_NUMBER: builtins.int
    MESSAGESTUBTYPE_FIELD_NUMBER: builtins.int
    CLEARMEDIA_FIELD_NUMBER: builtins.int
    MESSAGESTUBPARAMETERS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PAYMENTINFO_FIELD_NUMBER: builtins.int
    FINALLIVELOCATION_FIELD_NUMBER: builtins.int
    QUOTEDPAYMENTINFO_FIELD_NUMBER: builtins.int
    EPHEMERALSTARTTIMESTAMP_FIELD_NUMBER: builtins.int
    EPHEMERALDURATION_FIELD_NUMBER: builtins.int
    EPHEMERALOFFTOON_FIELD_NUMBER: builtins.int
    EPHEMERALOUTOFSYNC_FIELD_NUMBER: builtins.int
    BIZPRIVACYSTATUS_FIELD_NUMBER: builtins.int
    VERIFIEDBIZNAME_FIELD_NUMBER: builtins.int
    MEDIADATA_FIELD_NUMBER: builtins.int
    PHOTOCHANGE_FIELD_NUMBER: builtins.int
    USERRECEIPT_FIELD_NUMBER: builtins.int
    REACTIONS_FIELD_NUMBER: builtins.int
    QUOTEDSTICKERDATA_FIELD_NUMBER: builtins.int
    FUTUREPROOFDATA_FIELD_NUMBER: builtins.int
    STATUSPSA_FIELD_NUMBER: builtins.int
    POLLUPDATES_FIELD_NUMBER: builtins.int
    POLLADDITIONALMETADATA_FIELD_NUMBER: builtins.int
    AGENTID_FIELD_NUMBER: builtins.int
    STATUSALREADYVIEWED_FIELD_NUMBER: builtins.int
    MESSAGESECRET_FIELD_NUMBER: builtins.int
    KEEPINCHAT_FIELD_NUMBER: builtins.int
    ORIGINALSELFAUTHORUSERJIDSTRING_FIELD_NUMBER: builtins.int
    REVOKEMESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
    PININCHAT_FIELD_NUMBER: builtins.int
    PREMIUMMESSAGEINFO_FIELD_NUMBER: builtins.int
    IS1PBIZBOTMESSAGE_FIELD_NUMBER: builtins.int
    ISGROUPHISTORYMESSAGE_FIELD_NUMBER: builtins.int
    BOTMESSAGEINVOKERJID_FIELD_NUMBER: builtins.int
    COMMENTMETADATA_FIELD_NUMBER: builtins.int
    EVENTRESPONSES_FIELD_NUMBER: builtins.int
    REPORTINGTOKENINFO_FIELD_NUMBER: builtins.int
    NEWSLETTERSERVERID_FIELD_NUMBER: builtins.int
    EVENTADDITIONALMETADATA_FIELD_NUMBER: builtins.int
    ISMENTIONEDINSTATUS_FIELD_NUMBER: builtins.int
    STATUSMENTIONS_FIELD_NUMBER: builtins.int
    TARGETMESSAGEID_FIELD_NUMBER: builtins.int
    MESSAGEADDONS_FIELD_NUMBER: builtins.int
    STATUSMENTIONMESSAGEINFO_FIELD_NUMBER: builtins.int
    ISSUPPORTAIMESSAGE_FIELD_NUMBER: builtins.int
    STATUSMENTIONSOURCES_FIELD_NUMBER: builtins.int
    SUPPORTAICITATIONS_FIELD_NUMBER: builtins.int
    BOTTARGETID_FIELD_NUMBER: builtins.int
    messageTimestamp: builtins.int
    status: global___WebMessageInfo.Status.ValueType
    participant: builtins.str
    messageC2STimestamp: builtins.int
    ignore: builtins.bool
    starred: builtins.bool
    broadcast: builtins.bool
    pushName: builtins.str
    mediaCiphertextSHA256: builtins.bytes
    multicast: builtins.bool
    urlText: builtins.bool
    urlNumber: builtins.bool
    messageStubType: global___WebMessageInfo.StubType.ValueType
    clearMedia: builtins.bool
    duration: builtins.int
    ephemeralStartTimestamp: builtins.int
    ephemeralDuration: builtins.int
    ephemeralOffToOn: builtins.bool
    ephemeralOutOfSync: builtins.bool
    bizPrivacyStatus: global___WebMessageInfo.BizPrivacyStatus.ValueType
    verifiedBizName: builtins.str
    futureproofData: builtins.bytes
    agentID: builtins.str
    statusAlreadyViewed: builtins.bool
    messageSecret: builtins.bytes
    originalSelfAuthorUserJIDString: builtins.str
    revokeMessageTimestamp: builtins.int
    is1PBizBotMessage: builtins.bool
    isGroupHistoryMessage: builtins.bool
    botMessageInvokerJID: builtins.str
    newsletterServerID: builtins.int
    isMentionedInStatus: builtins.bool
    isSupportAiMessage: builtins.bool
    botTargetID: builtins.str
    @property
    def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
    @property
    def message(self) -> waE2E.WAWebProtobufsE2E_pb2.Message: ...
    @property
    def messageStubParameters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def paymentInfo(self) -> global___PaymentInfo: ...
    @property
    def finalLiveLocation(self) -> waE2E.WAWebProtobufsE2E_pb2.LiveLocationMessage: ...
    @property
    def quotedPaymentInfo(self) -> global___PaymentInfo: ...
    @property
    def mediaData(self) -> global___MediaData: ...
    @property
    def photoChange(self) -> global___PhotoChange: ...
    @property
    def userReceipt(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserReceipt]: ...
    @property
    def reactions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Reaction]: ...
    @property
    def quotedStickerData(self) -> global___MediaData: ...
    @property
    def statusPsa(self) -> global___StatusPSA: ...
    @property
    def pollUpdates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PollUpdate]: ...
    @property
    def pollAdditionalMetadata(self) -> global___PollAdditionalMetadata: ...
    @property
    def keepInChat(self) -> global___KeepInChat: ...
    @property
    def pinInChat(self) -> global___PinInChat: ...
    @property
    def premiumMessageInfo(self) -> global___PremiumMessageInfo: ...
    @property
    def commentMetadata(self) -> global___CommentMetadata: ...
    @property
    def eventResponses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventResponse]: ...
    @property
    def reportingTokenInfo(self) -> global___ReportingTokenInfo: ...
    @property
    def eventAdditionalMetadata(self) -> global___EventAdditionalMetadata: ...
    @property
    def statusMentions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def targetMessageID(self) -> waCommon.WACommon_pb2.MessageKey: ...
    @property
    def messageAddOns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageAddOn]: ...
    @property
    def statusMentionMessageInfo(self) -> global___StatusMentionMessage: ...
    @property
    def statusMentionSources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def supportAiCitations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Citation]: ...
    def __init__(
        self,
        *,
        key: waCommon.WACommon_pb2.MessageKey | None = ...,
        message: waE2E.WAWebProtobufsE2E_pb2.Message | None = ...,
        messageTimestamp: builtins.int | None = ...,
        status: global___WebMessageInfo.Status.ValueType | None = ...,
        participant: builtins.str | None = ...,
        messageC2STimestamp: builtins.int | None = ...,
        ignore: builtins.bool | None = ...,
        starred: builtins.bool | None = ...,
        broadcast: builtins.bool | None = ...,
        pushName: builtins.str | None = ...,
        mediaCiphertextSHA256: builtins.bytes | None = ...,
        multicast: builtins.bool | None = ...,
        urlText: builtins.bool | None = ...,
        urlNumber: builtins.bool | None = ...,
        messageStubType: global___WebMessageInfo.StubType.ValueType | None = ...,
        clearMedia: builtins.bool | None = ...,
        messageStubParameters: collections.abc.Iterable[builtins.str] | None = ...,
        duration: builtins.int | None = ...,
        labels: collections.abc.Iterable[builtins.str] | None = ...,
        paymentInfo: global___PaymentInfo | None = ...,
        finalLiveLocation: waE2E.WAWebProtobufsE2E_pb2.LiveLocationMessage | None = ...,
        quotedPaymentInfo: global___PaymentInfo | None = ...,
        ephemeralStartTimestamp: builtins.int | None = ...,
        ephemeralDuration: builtins.int | None = ...,
        ephemeralOffToOn: builtins.bool | None = ...,
        ephemeralOutOfSync: builtins.bool | None = ...,
        bizPrivacyStatus: global___WebMessageInfo.BizPrivacyStatus.ValueType | None = ...,
        verifiedBizName: builtins.str | None = ...,
        mediaData: global___MediaData | None = ...,
        photoChange: global___PhotoChange | None = ...,
        userReceipt: collections.abc.Iterable[global___UserReceipt] | None = ...,
        reactions: collections.abc.Iterable[global___Reaction] | None = ...,
        quotedStickerData: global___MediaData | None = ...,
        futureproofData: builtins.bytes | None = ...,
        statusPsa: global___StatusPSA | None = ...,
        pollUpdates: collections.abc.Iterable[global___PollUpdate] | None = ...,
        pollAdditionalMetadata: global___PollAdditionalMetadata | None = ...,
        agentID: builtins.str | None = ...,
        statusAlreadyViewed: builtins.bool | None = ...,
        messageSecret: builtins.bytes | None = ...,
        keepInChat: global___KeepInChat | None = ...,
        originalSelfAuthorUserJIDString: builtins.str | None = ...,
        revokeMessageTimestamp: builtins.int | None = ...,
        pinInChat: global___PinInChat | None = ...,
        premiumMessageInfo: global___PremiumMessageInfo | None = ...,
        is1PBizBotMessage: builtins.bool | None = ...,
        isGroupHistoryMessage: builtins.bool | None = ...,
        botMessageInvokerJID: builtins.str | None = ...,
        commentMetadata: global___CommentMetadata | None = ...,
        eventResponses: collections.abc.Iterable[global___EventResponse] | None = ...,
        reportingTokenInfo: global___ReportingTokenInfo | None = ...,
        newsletterServerID: builtins.int | None = ...,
        eventAdditionalMetadata: global___EventAdditionalMetadata | None = ...,
        isMentionedInStatus: builtins.bool | None = ...,
        statusMentions: collections.abc.Iterable[builtins.str] | None = ...,
        targetMessageID: waCommon.WACommon_pb2.MessageKey | None = ...,
        messageAddOns: collections.abc.Iterable[global___MessageAddOn] | None = ...,
        statusMentionMessageInfo: global___StatusMentionMessage | None = ...,
        isSupportAiMessage: builtins.bool | None = ...,
        statusMentionSources: collections.abc.Iterable[builtins.str] | None = ...,
        supportAiCitations: collections.abc.Iterable[global___Citation] | None = ...,
        botTargetID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["agentID", b"agentID", "bizPrivacyStatus", b"bizPrivacyStatus", "botMessageInvokerJID", b"botMessageInvokerJID", "botTargetID", b"botTargetID", "broadcast", b"broadcast", "clearMedia", b"clearMedia", "commentMetadata", b"commentMetadata", "duration", b"duration", "ephemeralDuration", b"ephemeralDuration", "ephemeralOffToOn", b"ephemeralOffToOn", "ephemeralOutOfSync", b"ephemeralOutOfSync", "ephemeralStartTimestamp", b"ephemeralStartTimestamp", "eventAdditionalMetadata", b"eventAdditionalMetadata", "finalLiveLocation", b"finalLiveLocation", "futureproofData", b"futureproofData", "ignore", b"ignore", "is1PBizBotMessage", b"is1PBizBotMessage", "isGroupHistoryMessage", b"isGroupHistoryMessage", "isMentionedInStatus", b"isMentionedInStatus", "isSupportAiMessage", b"isSupportAiMessage", "keepInChat", b"keepInChat", "key", b"key", "mediaCiphertextSHA256", b"mediaCiphertextSHA256", "mediaData", b"mediaData", "message", b"message", "messageC2STimestamp", b"messageC2STimestamp", "messageSecret", b"messageSecret", "messageStubType", b"messageStubType", "messageTimestamp", b"messageTimestamp", "multicast", b"multicast", "newsletterServerID", b"newsletterServerID", "originalSelfAuthorUserJIDString", b"originalSelfAuthorUserJIDString", "participant", b"participant", "paymentInfo", b"paymentInfo", "photoChange", b"photoChange", "pinInChat", b"pinInChat", "pollAdditionalMetadata", b"pollAdditionalMetadata", "premiumMessageInfo", b"premiumMessageInfo", "pushName", b"pushName", "quotedPaymentInfo", b"quotedPaymentInfo", "quotedStickerData", b"quotedStickerData", "reportingTokenInfo", b"reportingTokenInfo", "revokeMessageTimestamp", b"revokeMessageTimestamp", "starred", b"starred", "status", b"status", "statusAlreadyViewed", b"statusAlreadyViewed", "statusMentionMessageInfo", b"statusMentionMessageInfo", "statusPsa", b"statusPsa", "targetMessageID", b"targetMessageID", "urlNumber", b"urlNumber", "urlText", b"urlText", "verifiedBizName", b"verifiedBizName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agentID", b"agentID", "bizPrivacyStatus", b"bizPrivacyStatus", "botMessageInvokerJID", b"botMessageInvokerJID", "botTargetID", b"botTargetID", "broadcast", b"broadcast", "clearMedia", b"clearMedia", "commentMetadata", b"commentMetadata", "duration", b"duration", "ephemeralDuration", b"ephemeralDuration", "ephemeralOffToOn", b"ephemeralOffToOn", "ephemeralOutOfSync", b"ephemeralOutOfSync", "ephemeralStartTimestamp", b"ephemeralStartTimestamp", "eventAdditionalMetadata", b"eventAdditionalMetadata", "eventResponses", b"eventResponses", "finalLiveLocation", b"finalLiveLocation", "futureproofData", b"futureproofData", "ignore", b"ignore", "is1PBizBotMessage", b"is1PBizBotMessage", "isGroupHistoryMessage", b"isGroupHistoryMessage", "isMentionedInStatus", b"isMentionedInStatus", "isSupportAiMessage", b"isSupportAiMessage", "keepInChat", b"keepInChat", "key", b"key", "labels", b"labels", "mediaCiphertextSHA256", b"mediaCiphertextSHA256", "mediaData", b"mediaData", "message", b"message", "messageAddOns", b"messageAddOns", "messageC2STimestamp", b"messageC2STimestamp", "messageSecret", b"messageSecret", "messageStubParameters", b"messageStubParameters", "messageStubType", b"messageStubType", "messageTimestamp", b"messageTimestamp", "multicast", b"multicast", "newsletterServerID", b"newsletterServerID", "originalSelfAuthorUserJIDString", b"originalSelfAuthorUserJIDString", "participant", b"participant", "paymentInfo", b"paymentInfo", "photoChange", b"photoChange", "pinInChat", b"pinInChat", "pollAdditionalMetadata", b"pollAdditionalMetadata", "pollUpdates", b"pollUpdates", "premiumMessageInfo", b"premiumMessageInfo", "pushName", b"pushName", "quotedPaymentInfo", b"quotedPaymentInfo", "quotedStickerData", b"quotedStickerData", "reactions", b"reactions", "reportingTokenInfo", b"reportingTokenInfo", "revokeMessageTimestamp", b"revokeMessageTimestamp", "starred", b"starred", "status", b"status", "statusAlreadyViewed", b"statusAlreadyViewed", "statusMentionMessageInfo", b"statusMentionMessageInfo", "statusMentionSources", b"statusMentionSources", "statusMentions", b"statusMentions", "statusPsa", b"statusPsa", "supportAiCitations", b"supportAiCitations", "targetMessageID", b"targetMessageID", "urlNumber", b"urlNumber", "urlText", b"urlText", "userReceipt", b"userReceipt", "verifiedBizName", b"verifiedBizName"]) -> None: ...

global___WebMessageInfo = WebMessageInfo

@typing.final
class PaymentInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _TxnStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TxnStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PaymentInfo._TxnStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: PaymentInfo._TxnStatus.ValueType  # 0
        PENDING_SETUP: PaymentInfo._TxnStatus.ValueType  # 1
        PENDING_RECEIVER_SETUP: PaymentInfo._TxnStatus.ValueType  # 2
        INIT: PaymentInfo._TxnStatus.ValueType  # 3
        SUCCESS: PaymentInfo._TxnStatus.ValueType  # 4
        COMPLETED: PaymentInfo._TxnStatus.ValueType  # 5
        FAILED: PaymentInfo._TxnStatus.ValueType  # 6
        FAILED_RISK: PaymentInfo._TxnStatus.ValueType  # 7
        FAILED_PROCESSING: PaymentInfo._TxnStatus.ValueType  # 8
        FAILED_RECEIVER_PROCESSING: PaymentInfo._TxnStatus.ValueType  # 9
        FAILED_DA: PaymentInfo._TxnStatus.ValueType  # 10
        FAILED_DA_FINAL: PaymentInfo._TxnStatus.ValueType  # 11
        REFUNDED_TXN: PaymentInfo._TxnStatus.ValueType  # 12
        REFUND_FAILED: PaymentInfo._TxnStatus.ValueType  # 13
        REFUND_FAILED_PROCESSING: PaymentInfo._TxnStatus.ValueType  # 14
        REFUND_FAILED_DA: PaymentInfo._TxnStatus.ValueType  # 15
        EXPIRED_TXN: PaymentInfo._TxnStatus.ValueType  # 16
        AUTH_CANCELED: PaymentInfo._TxnStatus.ValueType  # 17
        AUTH_CANCEL_FAILED_PROCESSING: PaymentInfo._TxnStatus.ValueType  # 18
        AUTH_CANCEL_FAILED: PaymentInfo._TxnStatus.ValueType  # 19
        COLLECT_INIT: PaymentInfo._TxnStatus.ValueType  # 20
        COLLECT_SUCCESS: PaymentInfo._TxnStatus.ValueType  # 21
        COLLECT_FAILED: PaymentInfo._TxnStatus.ValueType  # 22
        COLLECT_FAILED_RISK: PaymentInfo._TxnStatus.ValueType  # 23
        COLLECT_REJECTED: PaymentInfo._TxnStatus.ValueType  # 24
        COLLECT_EXPIRED: PaymentInfo._TxnStatus.ValueType  # 25
        COLLECT_CANCELED: PaymentInfo._TxnStatus.ValueType  # 26
        COLLECT_CANCELLING: PaymentInfo._TxnStatus.ValueType  # 27
        IN_REVIEW: PaymentInfo._TxnStatus.ValueType  # 28
        REVERSAL_SUCCESS: PaymentInfo._TxnStatus.ValueType  # 29
        REVERSAL_PENDING: PaymentInfo._TxnStatus.ValueType  # 30
        REFUND_PENDING: PaymentInfo._TxnStatus.ValueType  # 31

    class TxnStatus(_TxnStatus, metaclass=_TxnStatusEnumTypeWrapper): ...
    UNKNOWN: PaymentInfo.TxnStatus.ValueType  # 0
    PENDING_SETUP: PaymentInfo.TxnStatus.ValueType  # 1
    PENDING_RECEIVER_SETUP: PaymentInfo.TxnStatus.ValueType  # 2
    INIT: PaymentInfo.TxnStatus.ValueType  # 3
    SUCCESS: PaymentInfo.TxnStatus.ValueType  # 4
    COMPLETED: PaymentInfo.TxnStatus.ValueType  # 5
    FAILED: PaymentInfo.TxnStatus.ValueType  # 6
    FAILED_RISK: PaymentInfo.TxnStatus.ValueType  # 7
    FAILED_PROCESSING: PaymentInfo.TxnStatus.ValueType  # 8
    FAILED_RECEIVER_PROCESSING: PaymentInfo.TxnStatus.ValueType  # 9
    FAILED_DA: PaymentInfo.TxnStatus.ValueType  # 10
    FAILED_DA_FINAL: PaymentInfo.TxnStatus.ValueType  # 11
    REFUNDED_TXN: PaymentInfo.TxnStatus.ValueType  # 12
    REFUND_FAILED: PaymentInfo.TxnStatus.ValueType  # 13
    REFUND_FAILED_PROCESSING: PaymentInfo.TxnStatus.ValueType  # 14
    REFUND_FAILED_DA: PaymentInfo.TxnStatus.ValueType  # 15
    EXPIRED_TXN: PaymentInfo.TxnStatus.ValueType  # 16
    AUTH_CANCELED: PaymentInfo.TxnStatus.ValueType  # 17
    AUTH_CANCEL_FAILED_PROCESSING: PaymentInfo.TxnStatus.ValueType  # 18
    AUTH_CANCEL_FAILED: PaymentInfo.TxnStatus.ValueType  # 19
    COLLECT_INIT: PaymentInfo.TxnStatus.ValueType  # 20
    COLLECT_SUCCESS: PaymentInfo.TxnStatus.ValueType  # 21
    COLLECT_FAILED: PaymentInfo.TxnStatus.ValueType  # 22
    COLLECT_FAILED_RISK: PaymentInfo.TxnStatus.ValueType  # 23
    COLLECT_REJECTED: PaymentInfo.TxnStatus.ValueType  # 24
    COLLECT_EXPIRED: PaymentInfo.TxnStatus.ValueType  # 25
    COLLECT_CANCELED: PaymentInfo.TxnStatus.ValueType  # 26
    COLLECT_CANCELLING: PaymentInfo.TxnStatus.ValueType  # 27
    IN_REVIEW: PaymentInfo.TxnStatus.ValueType  # 28
    REVERSAL_SUCCESS: PaymentInfo.TxnStatus.ValueType  # 29
    REVERSAL_PENDING: PaymentInfo.TxnStatus.ValueType  # 30
    REFUND_PENDING: PaymentInfo.TxnStatus.ValueType  # 31

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PaymentInfo._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN_STATUS: PaymentInfo._Status.ValueType  # 0
        PROCESSING: PaymentInfo._Status.ValueType  # 1
        SENT: PaymentInfo._Status.ValueType  # 2
        NEED_TO_ACCEPT: PaymentInfo._Status.ValueType  # 3
        COMPLETE: PaymentInfo._Status.ValueType  # 4
        COULD_NOT_COMPLETE: PaymentInfo._Status.ValueType  # 5
        REFUNDED: PaymentInfo._Status.ValueType  # 6
        EXPIRED: PaymentInfo._Status.ValueType  # 7
        REJECTED: PaymentInfo._Status.ValueType  # 8
        CANCELLED: PaymentInfo._Status.ValueType  # 9
        WAITING_FOR_PAYER: PaymentInfo._Status.ValueType  # 10
        WAITING: PaymentInfo._Status.ValueType  # 11

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    UNKNOWN_STATUS: PaymentInfo.Status.ValueType  # 0
    PROCESSING: PaymentInfo.Status.ValueType  # 1
    SENT: PaymentInfo.Status.ValueType  # 2
    NEED_TO_ACCEPT: PaymentInfo.Status.ValueType  # 3
    COMPLETE: PaymentInfo.Status.ValueType  # 4
    COULD_NOT_COMPLETE: PaymentInfo.Status.ValueType  # 5
    REFUNDED: PaymentInfo.Status.ValueType  # 6
    EXPIRED: PaymentInfo.Status.ValueType  # 7
    REJECTED: PaymentInfo.Status.ValueType  # 8
    CANCELLED: PaymentInfo.Status.ValueType  # 9
    WAITING_FOR_PAYER: PaymentInfo.Status.ValueType  # 10
    WAITING: PaymentInfo.Status.ValueType  # 11

    class _Currency:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CurrencyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PaymentInfo._Currency.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN_CURRENCY: PaymentInfo._Currency.ValueType  # 0
        INR: PaymentInfo._Currency.ValueType  # 1

    class Currency(_Currency, metaclass=_CurrencyEnumTypeWrapper): ...
    UNKNOWN_CURRENCY: PaymentInfo.Currency.ValueType  # 0
    INR: PaymentInfo.Currency.ValueType  # 1

    CURRENCYDEPRECATED_FIELD_NUMBER: builtins.int
    AMOUNT1000_FIELD_NUMBER: builtins.int
    RECEIVERJID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TRANSACTIONTIMESTAMP_FIELD_NUMBER: builtins.int
    REQUESTMESSAGEKEY_FIELD_NUMBER: builtins.int
    EXPIRYTIMESTAMP_FIELD_NUMBER: builtins.int
    FUTUREPROOFED_FIELD_NUMBER: builtins.int
    CURRENCY_FIELD_NUMBER: builtins.int
    TXNSTATUS_FIELD_NUMBER: builtins.int
    USENOVIFIATFORMAT_FIELD_NUMBER: builtins.int
    PRIMARYAMOUNT_FIELD_NUMBER: builtins.int
    EXCHANGEAMOUNT_FIELD_NUMBER: builtins.int
    currencyDeprecated: global___PaymentInfo.Currency.ValueType
    amount1000: builtins.int
    receiverJID: builtins.str
    status: global___PaymentInfo.Status.ValueType
    transactionTimestamp: builtins.int
    expiryTimestamp: builtins.int
    futureproofed: builtins.bool
    currency: builtins.str
    txnStatus: global___PaymentInfo.TxnStatus.ValueType
    useNoviFiatFormat: builtins.bool
    @property
    def requestMessageKey(self) -> waCommon.WACommon_pb2.MessageKey: ...
    @property
    def primaryAmount(self) -> waE2E.WAWebProtobufsE2E_pb2.Money: ...
    @property
    def exchangeAmount(self) -> waE2E.WAWebProtobufsE2E_pb2.Money: ...
    def __init__(
        self,
        *,
        currencyDeprecated: global___PaymentInfo.Currency.ValueType | None = ...,
        amount1000: builtins.int | None = ...,
        receiverJID: builtins.str | None = ...,
        status: global___PaymentInfo.Status.ValueType | None = ...,
        transactionTimestamp: builtins.int | None = ...,
        requestMessageKey: waCommon.WACommon_pb2.MessageKey | None = ...,
        expiryTimestamp: builtins.int | None = ...,
        futureproofed: builtins.bool | None = ...,
        currency: builtins.str | None = ...,
        txnStatus: global___PaymentInfo.TxnStatus.ValueType | None = ...,
        useNoviFiatFormat: builtins.bool | None = ...,
        primaryAmount: waE2E.WAWebProtobufsE2E_pb2.Money | None = ...,
        exchangeAmount: waE2E.WAWebProtobufsE2E_pb2.Money | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["amount1000", b"amount1000", "currency", b"currency", "currencyDeprecated", b"currencyDeprecated", "exchangeAmount", b"exchangeAmount", "expiryTimestamp", b"expiryTimestamp", "futureproofed", b"futureproofed", "primaryAmount", b"primaryAmount", "receiverJID", b"receiverJID", "requestMessageKey", b"requestMessageKey", "status", b"status", "transactionTimestamp", b"transactionTimestamp", "txnStatus", b"txnStatus", "useNoviFiatFormat", b"useNoviFiatFormat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["amount1000", b"amount1000", "currency", b"currency", "currencyDeprecated", b"currencyDeprecated", "exchangeAmount", b"exchangeAmount", "expiryTimestamp", b"expiryTimestamp", "futureproofed", b"futureproofed", "primaryAmount", b"primaryAmount", "receiverJID", b"receiverJID", "requestMessageKey", b"requestMessageKey", "status", b"status", "transactionTimestamp", b"transactionTimestamp", "txnStatus", b"txnStatus", "useNoviFiatFormat", b"useNoviFiatFormat"]) -> None: ...

global___PaymentInfo = PaymentInfo

@typing.final
class WebFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Flag:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FlagEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WebFeatures._Flag.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NOT_STARTED: WebFeatures._Flag.ValueType  # 0
        FORCE_UPGRADE: WebFeatures._Flag.ValueType  # 1
        DEVELOPMENT: WebFeatures._Flag.ValueType  # 2
        PRODUCTION: WebFeatures._Flag.ValueType  # 3

    class Flag(_Flag, metaclass=_FlagEnumTypeWrapper): ...
    NOT_STARTED: WebFeatures.Flag.ValueType  # 0
    FORCE_UPGRADE: WebFeatures.Flag.ValueType  # 1
    DEVELOPMENT: WebFeatures.Flag.ValueType  # 2
    PRODUCTION: WebFeatures.Flag.ValueType  # 3

    LABELSDISPLAY_FIELD_NUMBER: builtins.int
    VOIPINDIVIDUALOUTGOING_FIELD_NUMBER: builtins.int
    GROUPSV3_FIELD_NUMBER: builtins.int
    GROUPSV3CREATE_FIELD_NUMBER: builtins.int
    CHANGENUMBERV2_FIELD_NUMBER: builtins.int
    QUERYSTATUSV3THUMBNAIL_FIELD_NUMBER: builtins.int
    LIVELOCATIONS_FIELD_NUMBER: builtins.int
    QUERYVNAME_FIELD_NUMBER: builtins.int
    VOIPINDIVIDUALINCOMING_FIELD_NUMBER: builtins.int
    QUICKREPLIESQUERY_FIELD_NUMBER: builtins.int
    PAYMENTS_FIELD_NUMBER: builtins.int
    STICKERPACKQUERY_FIELD_NUMBER: builtins.int
    LIVELOCATIONSFINAL_FIELD_NUMBER: builtins.int
    LABELSEDIT_FIELD_NUMBER: builtins.int
    MEDIAUPLOAD_FIELD_NUMBER: builtins.int
    MEDIAUPLOADRICHQUICKREPLIES_FIELD_NUMBER: builtins.int
    VNAMEV2_FIELD_NUMBER: builtins.int
    VIDEOPLAYBACKURL_FIELD_NUMBER: builtins.int
    STATUSRANKING_FIELD_NUMBER: builtins.int
    VOIPINDIVIDUALVIDEO_FIELD_NUMBER: builtins.int
    THIRDPARTYSTICKERS_FIELD_NUMBER: builtins.int
    FREQUENTLYFORWARDEDSETTING_FIELD_NUMBER: builtins.int
    GROUPSV4JOINPERMISSION_FIELD_NUMBER: builtins.int
    RECENTSTICKERS_FIELD_NUMBER: builtins.int
    CATALOG_FIELD_NUMBER: builtins.int
    STARREDSTICKERS_FIELD_NUMBER: builtins.int
    VOIPGROUPCALL_FIELD_NUMBER: builtins.int
    TEMPLATEMESSAGE_FIELD_NUMBER: builtins.int
    TEMPLATEMESSAGEINTERACTIVITY_FIELD_NUMBER: builtins.int
    EPHEMERALMESSAGES_FIELD_NUMBER: builtins.int
    E2ENOTIFICATIONSYNC_FIELD_NUMBER: builtins.int
    RECENTSTICKERSV2_FIELD_NUMBER: builtins.int
    RECENTSTICKERSV3_FIELD_NUMBER: builtins.int
    USERNOTICE_FIELD_NUMBER: builtins.int
    SUPPORT_FIELD_NUMBER: builtins.int
    GROUPUIICLEANUP_FIELD_NUMBER: builtins.int
    GROUPDOGFOODINGINTERNALONLY_FIELD_NUMBER: builtins.int
    SETTINGSSYNC_FIELD_NUMBER: builtins.int
    ARCHIVEV2_FIELD_NUMBER: builtins.int
    EPHEMERALALLOWGROUPMEMBERS_FIELD_NUMBER: builtins.int
    EPHEMERAL24HDURATION_FIELD_NUMBER: builtins.int
    MDFORCEUPGRADE_FIELD_NUMBER: builtins.int
    DISAPPEARINGMODE_FIELD_NUMBER: builtins.int
    EXTERNALMDOPTINAVAILABLE_FIELD_NUMBER: builtins.int
    NODELETEMESSAGETIMELIMIT_FIELD_NUMBER: builtins.int
    labelsDisplay: global___WebFeatures.Flag.ValueType
    voipIndividualOutgoing: global___WebFeatures.Flag.ValueType
    groupsV3: global___WebFeatures.Flag.ValueType
    groupsV3Create: global___WebFeatures.Flag.ValueType
    changeNumberV2: global___WebFeatures.Flag.ValueType
    queryStatusV3Thumbnail: global___WebFeatures.Flag.ValueType
    liveLocations: global___WebFeatures.Flag.ValueType
    queryVname: global___WebFeatures.Flag.ValueType
    voipIndividualIncoming: global___WebFeatures.Flag.ValueType
    quickRepliesQuery: global___WebFeatures.Flag.ValueType
    payments: global___WebFeatures.Flag.ValueType
    stickerPackQuery: global___WebFeatures.Flag.ValueType
    liveLocationsFinal: global___WebFeatures.Flag.ValueType
    labelsEdit: global___WebFeatures.Flag.ValueType
    mediaUpload: global___WebFeatures.Flag.ValueType
    mediaUploadRichQuickReplies: global___WebFeatures.Flag.ValueType
    vnameV2: global___WebFeatures.Flag.ValueType
    videoPlaybackURL: global___WebFeatures.Flag.ValueType
    statusRanking: global___WebFeatures.Flag.ValueType
    voipIndividualVideo: global___WebFeatures.Flag.ValueType
    thirdPartyStickers: global___WebFeatures.Flag.ValueType
    frequentlyForwardedSetting: global___WebFeatures.Flag.ValueType
    groupsV4JoinPermission: global___WebFeatures.Flag.ValueType
    recentStickers: global___WebFeatures.Flag.ValueType
    catalog: global___WebFeatures.Flag.ValueType
    starredStickers: global___WebFeatures.Flag.ValueType
    voipGroupCall: global___WebFeatures.Flag.ValueType
    templateMessage: global___WebFeatures.Flag.ValueType
    templateMessageInteractivity: global___WebFeatures.Flag.ValueType
    ephemeralMessages: global___WebFeatures.Flag.ValueType
    e2ENotificationSync: global___WebFeatures.Flag.ValueType
    recentStickersV2: global___WebFeatures.Flag.ValueType
    recentStickersV3: global___WebFeatures.Flag.ValueType
    userNotice: global___WebFeatures.Flag.ValueType
    support: global___WebFeatures.Flag.ValueType
    groupUiiCleanup: global___WebFeatures.Flag.ValueType
    groupDogfoodingInternalOnly: global___WebFeatures.Flag.ValueType
    settingsSync: global___WebFeatures.Flag.ValueType
    archiveV2: global___WebFeatures.Flag.ValueType
    ephemeralAllowGroupMembers: global___WebFeatures.Flag.ValueType
    ephemeral24HDuration: global___WebFeatures.Flag.ValueType
    mdForceUpgrade: global___WebFeatures.Flag.ValueType
    disappearingMode: global___WebFeatures.Flag.ValueType
    externalMdOptInAvailable: global___WebFeatures.Flag.ValueType
    noDeleteMessageTimeLimit: global___WebFeatures.Flag.ValueType
    def __init__(
        self,
        *,
        labelsDisplay: global___WebFeatures.Flag.ValueType | None = ...,
        voipIndividualOutgoing: global___WebFeatures.Flag.ValueType | None = ...,
        groupsV3: global___WebFeatures.Flag.ValueType | None = ...,
        groupsV3Create: global___WebFeatures.Flag.ValueType | None = ...,
        changeNumberV2: global___WebFeatures.Flag.ValueType | None = ...,
        queryStatusV3Thumbnail: global___WebFeatures.Flag.ValueType | None = ...,
        liveLocations: global___WebFeatures.Flag.ValueType | None = ...,
        queryVname: global___WebFeatures.Flag.ValueType | None = ...,
        voipIndividualIncoming: global___WebFeatures.Flag.ValueType | None = ...,
        quickRepliesQuery: global___WebFeatures.Flag.ValueType | None = ...,
        payments: global___WebFeatures.Flag.ValueType | None = ...,
        stickerPackQuery: global___WebFeatures.Flag.ValueType | None = ...,
        liveLocationsFinal: global___WebFeatures.Flag.ValueType | None = ...,
        labelsEdit: global___WebFeatures.Flag.ValueType | None = ...,
        mediaUpload: global___WebFeatures.Flag.ValueType | None = ...,
        mediaUploadRichQuickReplies: global___WebFeatures.Flag.ValueType | None = ...,
        vnameV2: global___WebFeatures.Flag.ValueType | None = ...,
        videoPlaybackURL: global___WebFeatures.Flag.ValueType | None = ...,
        statusRanking: global___WebFeatures.Flag.ValueType | None = ...,
        voipIndividualVideo: global___WebFeatures.Flag.ValueType | None = ...,
        thirdPartyStickers: global___WebFeatures.Flag.ValueType | None = ...,
        frequentlyForwardedSetting: global___WebFeatures.Flag.ValueType | None = ...,
        groupsV4JoinPermission: global___WebFeatures.Flag.ValueType | None = ...,
        recentStickers: global___WebFeatures.Flag.ValueType | None = ...,
        catalog: global___WebFeatures.Flag.ValueType | None = ...,
        starredStickers: global___WebFeatures.Flag.ValueType | None = ...,
        voipGroupCall: global___WebFeatures.Flag.ValueType | None = ...,
        templateMessage: global___WebFeatures.Flag.ValueType | None = ...,
        templateMessageInteractivity: global___WebFeatures.Flag.ValueType | None = ...,
        ephemeralMessages: global___WebFeatures.Flag.ValueType | None = ...,
        e2ENotificationSync: global___WebFeatures.Flag.ValueType | None = ...,
        recentStickersV2: global___WebFeatures.Flag.ValueType | None = ...,
        recentStickersV3: global___WebFeatures.Flag.ValueType | None = ...,
        userNotice: global___WebFeatures.Flag.ValueType | None = ...,
        support: global___WebFeatures.Flag.ValueType | None = ...,
        groupUiiCleanup: global___WebFeatures.Flag.ValueType | None = ...,
        groupDogfoodingInternalOnly: global___WebFeatures.Flag.ValueType | None = ...,
        settingsSync: global___WebFeatures.Flag.ValueType | None = ...,
        archiveV2: global___WebFeatures.Flag.ValueType | None = ...,
        ephemeralAllowGroupMembers: global___WebFeatures.Flag.ValueType | None = ...,
        ephemeral24HDuration: global___WebFeatures.Flag.ValueType | None = ...,
        mdForceUpgrade: global___WebFeatures.Flag.ValueType | None = ...,
        disappearingMode: global___WebFeatures.Flag.ValueType | None = ...,
        externalMdOptInAvailable: global___WebFeatures.Flag.ValueType | None = ...,
        noDeleteMessageTimeLimit: global___WebFeatures.Flag.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["archiveV2", b"archiveV2", "catalog", b"catalog", "changeNumberV2", b"changeNumberV2", "disappearingMode", b"disappearingMode", "e2ENotificationSync", b"e2ENotificationSync", "ephemeral24HDuration", b"ephemeral24HDuration", "ephemeralAllowGroupMembers", b"ephemeralAllowGroupMembers", "ephemeralMessages", b"ephemeralMessages", "externalMdOptInAvailable", b"externalMdOptInAvailable", "frequentlyForwardedSetting", b"frequentlyForwardedSetting", "groupDogfoodingInternalOnly", b"groupDogfoodingInternalOnly", "groupUiiCleanup", b"groupUiiCleanup", "groupsV3", b"groupsV3", "groupsV3Create", b"groupsV3Create", "groupsV4JoinPermission", b"groupsV4JoinPermission", "labelsDisplay", b"labelsDisplay", "labelsEdit", b"labelsEdit", "liveLocations", b"liveLocations", "liveLocationsFinal", b"liveLocationsFinal", "mdForceUpgrade", b"mdForceUpgrade", "mediaUpload", b"mediaUpload", "mediaUploadRichQuickReplies", b"mediaUploadRichQuickReplies", "noDeleteMessageTimeLimit", b"noDeleteMessageTimeLimit", "payments", b"payments", "queryStatusV3Thumbnail", b"queryStatusV3Thumbnail", "queryVname", b"queryVname", "quickRepliesQuery", b"quickRepliesQuery", "recentStickers", b"recentStickers", "recentStickersV2", b"recentStickersV2", "recentStickersV3", b"recentStickersV3", "settingsSync", b"settingsSync", "starredStickers", b"starredStickers", "statusRanking", b"statusRanking", "stickerPackQuery", b"stickerPackQuery", "support", b"support", "templateMessage", b"templateMessage", "templateMessageInteractivity", b"templateMessageInteractivity", "thirdPartyStickers", b"thirdPartyStickers", "userNotice", b"userNotice", "videoPlaybackURL", b"videoPlaybackURL", "vnameV2", b"vnameV2", "voipGroupCall", b"voipGroupCall", "voipIndividualIncoming", b"voipIndividualIncoming", "voipIndividualOutgoing", b"voipIndividualOutgoing", "voipIndividualVideo", b"voipIndividualVideo"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["archiveV2", b"archiveV2", "catalog", b"catalog", "changeNumberV2", b"changeNumberV2", "disappearingMode", b"disappearingMode", "e2ENotificationSync", b"e2ENotificationSync", "ephemeral24HDuration", b"ephemeral24HDuration", "ephemeralAllowGroupMembers", b"ephemeralAllowGroupMembers", "ephemeralMessages", b"ephemeralMessages", "externalMdOptInAvailable", b"externalMdOptInAvailable", "frequentlyForwardedSetting", b"frequentlyForwardedSetting", "groupDogfoodingInternalOnly", b"groupDogfoodingInternalOnly", "groupUiiCleanup", b"groupUiiCleanup", "groupsV3", b"groupsV3", "groupsV3Create", b"groupsV3Create", "groupsV4JoinPermission", b"groupsV4JoinPermission", "labelsDisplay", b"labelsDisplay", "labelsEdit", b"labelsEdit", "liveLocations", b"liveLocations", "liveLocationsFinal", b"liveLocationsFinal", "mdForceUpgrade", b"mdForceUpgrade", "mediaUpload", b"mediaUpload", "mediaUploadRichQuickReplies", b"mediaUploadRichQuickReplies", "noDeleteMessageTimeLimit", b"noDeleteMessageTimeLimit", "payments", b"payments", "queryStatusV3Thumbnail", b"queryStatusV3Thumbnail", "queryVname", b"queryVname", "quickRepliesQuery", b"quickRepliesQuery", "recentStickers", b"recentStickers", "recentStickersV2", b"recentStickersV2", "recentStickersV3", b"recentStickersV3", "settingsSync", b"settingsSync", "starredStickers", b"starredStickers", "statusRanking", b"statusRanking", "stickerPackQuery", b"stickerPackQuery", "support", b"support", "templateMessage", b"templateMessage", "templateMessageInteractivity", b"templateMessageInteractivity", "thirdPartyStickers", b"thirdPartyStickers", "userNotice", b"userNotice", "videoPlaybackURL", b"videoPlaybackURL", "vnameV2", b"vnameV2", "voipGroupCall", b"voipGroupCall", "voipIndividualIncoming", b"voipIndividualIncoming", "voipIndividualOutgoing", b"voipIndividualOutgoing", "voipIndividualVideo", b"voipIndividualVideo"]) -> None: ...

global___WebFeatures = WebFeatures

@typing.final
class PinInChat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PinInChat._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN_TYPE: PinInChat._Type.ValueType  # 0
        PIN_FOR_ALL: PinInChat._Type.ValueType  # 1
        UNPIN_FOR_ALL: PinInChat._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    UNKNOWN_TYPE: PinInChat.Type.ValueType  # 0
    PIN_FOR_ALL: PinInChat.Type.ValueType  # 1
    UNPIN_FOR_ALL: PinInChat.Type.ValueType  # 2

    TYPE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    SENDERTIMESTAMPMS_FIELD_NUMBER: builtins.int
    SERVERTIMESTAMPMS_FIELD_NUMBER: builtins.int
    MESSAGEADDONCONTEXTINFO_FIELD_NUMBER: builtins.int
    type: global___PinInChat.Type.ValueType
    senderTimestampMS: builtins.int
    serverTimestampMS: builtins.int
    @property
    def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
    @property
    def messageAddOnContextInfo(self) -> global___MessageAddOnContextInfo: ...
    def __init__(
        self,
        *,
        type: global___PinInChat.Type.ValueType | None = ...,
        key: waCommon.WACommon_pb2.MessageKey | None = ...,
        senderTimestampMS: builtins.int | None = ...,
        serverTimestampMS: builtins.int | None = ...,
        messageAddOnContextInfo: global___MessageAddOnContextInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["key", b"key", "messageAddOnContextInfo", b"messageAddOnContextInfo", "senderTimestampMS", b"senderTimestampMS", "serverTimestampMS", b"serverTimestampMS", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "messageAddOnContextInfo", b"messageAddOnContextInfo", "senderTimestampMS", b"senderTimestampMS", "serverTimestampMS", b"serverTimestampMS", "type", b"type"]) -> None: ...

global___PinInChat = PinInChat

@typing.final
class MessageAddOn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MessageAddOnType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MessageAddOnTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MessageAddOn._MessageAddOnType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNDEFINED: MessageAddOn._MessageAddOnType.ValueType  # 0
        REACTION: MessageAddOn._MessageAddOnType.ValueType  # 1
        EVENT_RESPONSE: MessageAddOn._MessageAddOnType.ValueType  # 2
        POLL_UPDATE: MessageAddOn._MessageAddOnType.ValueType  # 3
        PIN_IN_CHAT: MessageAddOn._MessageAddOnType.ValueType  # 4

    class MessageAddOnType(_MessageAddOnType, metaclass=_MessageAddOnTypeEnumTypeWrapper): ...
    UNDEFINED: MessageAddOn.MessageAddOnType.ValueType  # 0
    REACTION: MessageAddOn.MessageAddOnType.ValueType  # 1
    EVENT_RESPONSE: MessageAddOn.MessageAddOnType.ValueType  # 2
    POLL_UPDATE: MessageAddOn.MessageAddOnType.ValueType  # 3
    PIN_IN_CHAT: MessageAddOn.MessageAddOnType.ValueType  # 4

    MESSAGEADDONTYPE_FIELD_NUMBER: builtins.int
    MESSAGEADDON_FIELD_NUMBER: builtins.int
    SENDERTIMESTAMPMS_FIELD_NUMBER: builtins.int
    SERVERTIMESTAMPMS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ADDONCONTEXTINFO_FIELD_NUMBER: builtins.int
    MESSAGEADDONKEY_FIELD_NUMBER: builtins.int
    LEGACYMESSAGE_FIELD_NUMBER: builtins.int
    messageAddOnType: global___MessageAddOn.MessageAddOnType.ValueType
    senderTimestampMS: builtins.int
    serverTimestampMS: builtins.int
    status: global___WebMessageInfo.Status.ValueType
    @property
    def messageAddOn(self) -> waE2E.WAWebProtobufsE2E_pb2.Message: ...
    @property
    def addOnContextInfo(self) -> global___MessageAddOnContextInfo: ...
    @property
    def messageAddOnKey(self) -> waCommon.WACommon_pb2.MessageKey: ...
    @property
    def legacyMessage(self) -> global___LegacyMessage: ...
    def __init__(
        self,
        *,
        messageAddOnType: global___MessageAddOn.MessageAddOnType.ValueType | None = ...,
        messageAddOn: waE2E.WAWebProtobufsE2E_pb2.Message | None = ...,
        senderTimestampMS: builtins.int | None = ...,
        serverTimestampMS: builtins.int | None = ...,
        status: global___WebMessageInfo.Status.ValueType | None = ...,
        addOnContextInfo: global___MessageAddOnContextInfo | None = ...,
        messageAddOnKey: waCommon.WACommon_pb2.MessageKey | None = ...,
        legacyMessage: global___LegacyMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["addOnContextInfo", b"addOnContextInfo", "legacyMessage", b"legacyMessage", "messageAddOn", b"messageAddOn", "messageAddOnKey", b"messageAddOnKey", "messageAddOnType", b"messageAddOnType", "senderTimestampMS", b"senderTimestampMS", "serverTimestampMS", b"serverTimestampMS", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["addOnContextInfo", b"addOnContextInfo", "legacyMessage", b"legacyMessage", "messageAddOn", b"messageAddOn", "messageAddOnKey", b"messageAddOnKey", "messageAddOnType", b"messageAddOnType", "senderTimestampMS", b"senderTimestampMS", "serverTimestampMS", b"serverTimestampMS", "status", b"status"]) -> None: ...

global___MessageAddOn = MessageAddOn

@typing.final
class CommentMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMENTPARENTKEY_FIELD_NUMBER: builtins.int
    REPLYCOUNT_FIELD_NUMBER: builtins.int
    replyCount: builtins.int
    @property
    def commentParentKey(self) -> waCommon.WACommon_pb2.MessageKey: ...
    def __init__(
        self,
        *,
        commentParentKey: waCommon.WACommon_pb2.MessageKey | None = ...,
        replyCount: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["commentParentKey", b"commentParentKey", "replyCount", b"replyCount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["commentParentKey", b"commentParentKey", "replyCount", b"replyCount"]) -> None: ...

global___CommentMetadata = CommentMetadata

@typing.final
class WebNotificationsInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    UNREADCHATS_FIELD_NUMBER: builtins.int
    NOTIFYMESSAGECOUNT_FIELD_NUMBER: builtins.int
    NOTIFYMESSAGES_FIELD_NUMBER: builtins.int
    timestamp: builtins.int
    unreadChats: builtins.int
    notifyMessageCount: builtins.int
    @property
    def notifyMessages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WebMessageInfo]: ...
    def __init__(
        self,
        *,
        timestamp: builtins.int | None = ...,
        unreadChats: builtins.int | None = ...,
        notifyMessageCount: builtins.int | None = ...,
        notifyMessages: collections.abc.Iterable[global___WebMessageInfo] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["notifyMessageCount", b"notifyMessageCount", "timestamp", b"timestamp", "unreadChats", b"unreadChats"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["notifyMessageCount", b"notifyMessageCount", "notifyMessages", b"notifyMessages", "timestamp", b"timestamp", "unreadChats", b"unreadChats"]) -> None: ...

global___WebNotificationsInfo = WebNotificationsInfo

@typing.final
class NotificationMessageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    MESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
    PARTICIPANT_FIELD_NUMBER: builtins.int
    messageTimestamp: builtins.int
    participant: builtins.str
    @property
    def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
    @property
    def message(self) -> waE2E.WAWebProtobufsE2E_pb2.Message: ...
    def __init__(
        self,
        *,
        key: waCommon.WACommon_pb2.MessageKey | None = ...,
        message: waE2E.WAWebProtobufsE2E_pb2.Message | None = ...,
        messageTimestamp: builtins.int | None = ...,
        participant: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["key", b"key", "message", b"message", "messageTimestamp", b"messageTimestamp", "participant", b"participant"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "message", b"message", "messageTimestamp", b"messageTimestamp", "participant", b"participant"]) -> None: ...

global___NotificationMessageInfo = NotificationMessageInfo

@typing.final
class ReportingTokenInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPORTINGTAG_FIELD_NUMBER: builtins.int
    reportingTag: builtins.bytes
    def __init__(
        self,
        *,
        reportingTag: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["reportingTag", b"reportingTag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["reportingTag", b"reportingTag"]) -> None: ...

global___ReportingTokenInfo = ReportingTokenInfo

@typing.final
class MediaData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCALPATH_FIELD_NUMBER: builtins.int
    localPath: builtins.str
    def __init__(
        self,
        *,
        localPath: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["localPath", b"localPath"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["localPath", b"localPath"]) -> None: ...

global___MediaData = MediaData

@typing.final
class PhotoChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLDPHOTO_FIELD_NUMBER: builtins.int
    NEWPHOTO_FIELD_NUMBER: builtins.int
    NEWPHOTOID_FIELD_NUMBER: builtins.int
    oldPhoto: builtins.bytes
    newPhoto: builtins.bytes
    newPhotoID: builtins.int
    def __init__(
        self,
        *,
        oldPhoto: builtins.bytes | None = ...,
        newPhoto: builtins.bytes | None = ...,
        newPhotoID: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["newPhoto", b"newPhoto", "newPhotoID", b"newPhotoID", "oldPhoto", b"oldPhoto"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["newPhoto", b"newPhoto", "newPhotoID", b"newPhotoID", "oldPhoto", b"oldPhoto"]) -> None: ...

global___PhotoChange = PhotoChange

@typing.final
class StatusPSA(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPAIGNID_FIELD_NUMBER: builtins.int
    CAMPAIGNEXPIRATIONTIMESTAMP_FIELD_NUMBER: builtins.int
    campaignID: builtins.int
    campaignExpirationTimestamp: builtins.int
    def __init__(
        self,
        *,
        campaignID: builtins.int | None = ...,
        campaignExpirationTimestamp: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["campaignExpirationTimestamp", b"campaignExpirationTimestamp", "campaignID", b"campaignID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["campaignExpirationTimestamp", b"campaignExpirationTimestamp", "campaignID", b"campaignID"]) -> None: ...

global___StatusPSA = StatusPSA

@typing.final
class UserReceipt(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERJID_FIELD_NUMBER: builtins.int
    RECEIPTTIMESTAMP_FIELD_NUMBER: builtins.int
    READTIMESTAMP_FIELD_NUMBER: builtins.int
    PLAYEDTIMESTAMP_FIELD_NUMBER: builtins.int
    PENDINGDEVICEJID_FIELD_NUMBER: builtins.int
    DELIVEREDDEVICEJID_FIELD_NUMBER: builtins.int
    userJID: builtins.str
    receiptTimestamp: builtins.int
    readTimestamp: builtins.int
    playedTimestamp: builtins.int
    @property
    def pendingDeviceJID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def deliveredDeviceJID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        userJID: builtins.str | None = ...,
        receiptTimestamp: builtins.int | None = ...,
        readTimestamp: builtins.int | None = ...,
        playedTimestamp: builtins.int | None = ...,
        pendingDeviceJID: collections.abc.Iterable[builtins.str] | None = ...,
        deliveredDeviceJID: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["playedTimestamp", b"playedTimestamp", "readTimestamp", b"readTimestamp", "receiptTimestamp", b"receiptTimestamp", "userJID", b"userJID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deliveredDeviceJID", b"deliveredDeviceJID", "pendingDeviceJID", b"pendingDeviceJID", "playedTimestamp", b"playedTimestamp", "readTimestamp", b"readTimestamp", "receiptTimestamp", b"receiptTimestamp", "userJID", b"userJID"]) -> None: ...

global___UserReceipt = UserReceipt

@typing.final
class Reaction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    GROUPINGKEY_FIELD_NUMBER: builtins.int
    SENDERTIMESTAMPMS_FIELD_NUMBER: builtins.int
    UNREAD_FIELD_NUMBER: builtins.int
    text: builtins.str
    groupingKey: builtins.str
    senderTimestampMS: builtins.int
    unread: builtins.bool
    @property
    def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
    def __init__(
        self,
        *,
        key: waCommon.WACommon_pb2.MessageKey | None = ...,
        text: builtins.str | None = ...,
        groupingKey: builtins.str | None = ...,
        senderTimestampMS: builtins.int | None = ...,
        unread: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["groupingKey", b"groupingKey", "key", b"key", "senderTimestampMS", b"senderTimestampMS", "text", b"text", "unread", b"unread"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["groupingKey", b"groupingKey", "key", b"key", "senderTimestampMS", b"senderTimestampMS", "text", b"text", "unread", b"unread"]) -> None: ...

global___Reaction = Reaction

@typing.final
class PollUpdate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLLUPDATEMESSAGEKEY_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    SENDERTIMESTAMPMS_FIELD_NUMBER: builtins.int
    SERVERTIMESTAMPMS_FIELD_NUMBER: builtins.int
    UNREAD_FIELD_NUMBER: builtins.int
    senderTimestampMS: builtins.int
    serverTimestampMS: builtins.int
    unread: builtins.bool
    @property
    def pollUpdateMessageKey(self) -> waCommon.WACommon_pb2.MessageKey: ...
    @property
    def vote(self) -> waE2E.WAWebProtobufsE2E_pb2.PollVoteMessage: ...
    def __init__(
        self,
        *,
        pollUpdateMessageKey: waCommon.WACommon_pb2.MessageKey | None = ...,
        vote: waE2E.WAWebProtobufsE2E_pb2.PollVoteMessage | None = ...,
        senderTimestampMS: builtins.int | None = ...,
        serverTimestampMS: builtins.int | None = ...,
        unread: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pollUpdateMessageKey", b"pollUpdateMessageKey", "senderTimestampMS", b"senderTimestampMS", "serverTimestampMS", b"serverTimestampMS", "unread", b"unread", "vote", b"vote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pollUpdateMessageKey", b"pollUpdateMessageKey", "senderTimestampMS", b"senderTimestampMS", "serverTimestampMS", b"serverTimestampMS", "unread", b"unread", "vote", b"vote"]) -> None: ...

global___PollUpdate = PollUpdate

@typing.final
class PollAdditionalMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLLINVALIDATED_FIELD_NUMBER: builtins.int
    pollInvalidated: builtins.bool
    def __init__(
        self,
        *,
        pollInvalidated: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pollInvalidated", b"pollInvalidated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pollInvalidated", b"pollInvalidated"]) -> None: ...

global___PollAdditionalMetadata = PollAdditionalMetadata

@typing.final
class EventAdditionalMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISSTALE_FIELD_NUMBER: builtins.int
    isStale: builtins.bool
    def __init__(
        self,
        *,
        isStale: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isStale", b"isStale"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isStale", b"isStale"]) -> None: ...

global___EventAdditionalMetadata = EventAdditionalMetadata

@typing.final
class KeepInChat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEEPTYPE_FIELD_NUMBER: builtins.int
    SERVERTIMESTAMP_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    DEVICEJID_FIELD_NUMBER: builtins.int
    CLIENTTIMESTAMPMS_FIELD_NUMBER: builtins.int
    SERVERTIMESTAMPMS_FIELD_NUMBER: builtins.int
    keepType: waE2E.WAWebProtobufsE2E_pb2.KeepType.ValueType
    serverTimestamp: builtins.int
    deviceJID: builtins.str
    clientTimestampMS: builtins.int
    serverTimestampMS: builtins.int
    @property
    def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
    def __init__(
        self,
        *,
        keepType: waE2E.WAWebProtobufsE2E_pb2.KeepType.ValueType | None = ...,
        serverTimestamp: builtins.int | None = ...,
        key: waCommon.WACommon_pb2.MessageKey | None = ...,
        deviceJID: builtins.str | None = ...,
        clientTimestampMS: builtins.int | None = ...,
        serverTimestampMS: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clientTimestampMS", b"clientTimestampMS", "deviceJID", b"deviceJID", "keepType", b"keepType", "key", b"key", "serverTimestamp", b"serverTimestamp", "serverTimestampMS", b"serverTimestampMS"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clientTimestampMS", b"clientTimestampMS", "deviceJID", b"deviceJID", "keepType", b"keepType", "key", b"key", "serverTimestamp", b"serverTimestamp", "serverTimestampMS", b"serverTimestampMS"]) -> None: ...

global___KeepInChat = KeepInChat

@typing.final
class MessageAddOnContextInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGEADDONDURATIONINSECS_FIELD_NUMBER: builtins.int
    MESSAGEADDONEXPIRYTYPE_FIELD_NUMBER: builtins.int
    messageAddOnDurationInSecs: builtins.int
    messageAddOnExpiryType: waE2E.WAWebProtobufsE2E_pb2.MessageContextInfo.MessageAddonExpiryType.ValueType
    def __init__(
        self,
        *,
        messageAddOnDurationInSecs: builtins.int | None = ...,
        messageAddOnExpiryType: waE2E.WAWebProtobufsE2E_pb2.MessageContextInfo.MessageAddonExpiryType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["messageAddOnDurationInSecs", b"messageAddOnDurationInSecs", "messageAddOnExpiryType", b"messageAddOnExpiryType"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["messageAddOnDurationInSecs", b"messageAddOnDurationInSecs", "messageAddOnExpiryType", b"messageAddOnExpiryType"]) -> None: ...

global___MessageAddOnContextInfo = MessageAddOnContextInfo

@typing.final
class PremiumMessageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVERCAMPAIGNID_FIELD_NUMBER: builtins.int
    serverCampaignID: builtins.str
    def __init__(
        self,
        *,
        serverCampaignID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["serverCampaignID", b"serverCampaignID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["serverCampaignID", b"serverCampaignID"]) -> None: ...

global___PremiumMessageInfo = PremiumMessageInfo

@typing.final
class EventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTRESPONSEMESSAGEKEY_FIELD_NUMBER: builtins.int
    TIMESTAMPMS_FIELD_NUMBER: builtins.int
    EVENTRESPONSEMESSAGE_FIELD_NUMBER: builtins.int
    UNREAD_FIELD_NUMBER: builtins.int
    timestampMS: builtins.int
    unread: builtins.bool
    @property
    def eventResponseMessageKey(self) -> waCommon.WACommon_pb2.MessageKey: ...
    @property
    def eventResponseMessage(self) -> waE2E.WAWebProtobufsE2E_pb2.EventResponseMessage: ...
    def __init__(
        self,
        *,
        eventResponseMessageKey: waCommon.WACommon_pb2.MessageKey | None = ...,
        timestampMS: builtins.int | None = ...,
        eventResponseMessage: waE2E.WAWebProtobufsE2E_pb2.EventResponseMessage | None = ...,
        unread: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["eventResponseMessage", b"eventResponseMessage", "eventResponseMessageKey", b"eventResponseMessageKey", "timestampMS", b"timestampMS", "unread", b"unread"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["eventResponseMessage", b"eventResponseMessage", "eventResponseMessageKey", b"eventResponseMessageKey", "timestampMS", b"timestampMS", "unread", b"unread"]) -> None: ...

global___EventResponse = EventResponse

@typing.final
class LegacyMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTRESPONSEMESSAGE_FIELD_NUMBER: builtins.int
    POLLVOTE_FIELD_NUMBER: builtins.int
    @property
    def eventResponseMessage(self) -> waE2E.WAWebProtobufsE2E_pb2.EventResponseMessage: ...
    @property
    def pollVote(self) -> waE2E.WAWebProtobufsE2E_pb2.PollVoteMessage: ...
    def __init__(
        self,
        *,
        eventResponseMessage: waE2E.WAWebProtobufsE2E_pb2.EventResponseMessage | None = ...,
        pollVote: waE2E.WAWebProtobufsE2E_pb2.PollVoteMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["eventResponseMessage", b"eventResponseMessage", "pollVote", b"pollVote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["eventResponseMessage", b"eventResponseMessage", "pollVote", b"pollVote"]) -> None: ...

global___LegacyMessage = LegacyMessage

@typing.final
class StatusMentionMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUOTEDSTATUS_FIELD_NUMBER: builtins.int
    @property
    def quotedStatus(self) -> waE2E.WAWebProtobufsE2E_pb2.Message: ...
    def __init__(
        self,
        *,
        quotedStatus: waE2E.WAWebProtobufsE2E_pb2.Message | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["quotedStatus", b"quotedStatus"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["quotedStatus", b"quotedStatus"]) -> None: ...

global___StatusMentionMessage = StatusMentionMessage

@typing.final
class Citation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    CMSID_FIELD_NUMBER: builtins.int
    IMAGEURL_FIELD_NUMBER: builtins.int
    title: builtins.str
    subtitle: builtins.str
    cmsID: builtins.str
    imageURL: builtins.str
    def __init__(
        self,
        *,
        title: builtins.str | None = ...,
        subtitle: builtins.str | None = ...,
        cmsID: builtins.str | None = ...,
        imageURL: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cmsID", b"cmsID", "imageURL", b"imageURL", "subtitle", b"subtitle", "title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cmsID", b"cmsID", "imageURL", b"imageURL", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___Citation = Citation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MediaEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ProgressiveJpegDetails(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SCANLENGTHS_FIELD_NUMBER: builtins.int
        SIDECAR_FIELD_NUMBER: builtins.int
        sidecar: builtins.bytes
        @property
        def scanLengths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
        def __init__(
            self,
            *,
            scanLengths: collections.abc.Iterable[builtins.int] | None = ...,
            sidecar: builtins.bytes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["sidecar", b"sidecar"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["scanLengths", b"scanLengths", "sidecar", b"sidecar"]) -> None: ...

    @typing.final
    class DownloadableThumbnail(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FILESHA256_FIELD_NUMBER: builtins.int
        FILEENCSHA256_FIELD_NUMBER: builtins.int
        DIRECTPATH_FIELD_NUMBER: builtins.int
        MEDIAKEY_FIELD_NUMBER: builtins.int
        MEDIAKEYTIMESTAMP_FIELD_NUMBER: builtins.int
        OBJECTID_FIELD_NUMBER: builtins.int
        fileSHA256: builtins.bytes
        fileEncSHA256: builtins.bytes
        directPath: builtins.str
        mediaKey: builtins.bytes
        mediaKeyTimestamp: builtins.int
        objectID: builtins.str
        def __init__(
            self,
            *,
            fileSHA256: builtins.bytes | None = ...,
            fileEncSHA256: builtins.bytes | None = ...,
            directPath: builtins.str | None = ...,
            mediaKey: builtins.bytes | None = ...,
            mediaKeyTimestamp: builtins.int | None = ...,
            objectID: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp", "objectID", b"objectID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp", "objectID", b"objectID"]) -> None: ...

    FILESHA256_FIELD_NUMBER: builtins.int
    MEDIAKEY_FIELD_NUMBER: builtins.int
    FILEENCSHA256_FIELD_NUMBER: builtins.int
    DIRECTPATH_FIELD_NUMBER: builtins.int
    MEDIAKEYTIMESTAMP_FIELD_NUMBER: builtins.int
    SERVERMEDIATYPE_FIELD_NUMBER: builtins.int
    UPLOADTOKEN_FIELD_NUMBER: builtins.int
    VALIDATEDTIMESTAMP_FIELD_NUMBER: builtins.int
    SIDECAR_FIELD_NUMBER: builtins.int
    OBJECTID_FIELD_NUMBER: builtins.int
    FBID_FIELD_NUMBER: builtins.int
    DOWNLOADABLETHUMBNAIL_FIELD_NUMBER: builtins.int
    HANDLE_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    PROGRESSIVEJPEGDETAILS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    LASTDOWNLOADATTEMPTTIMESTAMP_FIELD_NUMBER: builtins.int
    fileSHA256: builtins.bytes
    mediaKey: builtins.bytes
    fileEncSHA256: builtins.bytes
    directPath: builtins.str
    mediaKeyTimestamp: builtins.int
    serverMediaType: builtins.str
    uploadToken: builtins.bytes
    validatedTimestamp: builtins.bytes
    sidecar: builtins.bytes
    objectID: builtins.str
    FBID: builtins.str
    handle: builtins.str
    filename: builtins.str
    size: builtins.int
    lastDownloadAttemptTimestamp: builtins.int
    @property
    def downloadableThumbnail(self) -> global___MediaEntry.DownloadableThumbnail: ...
    @property
    def progressiveJPEGDetails(self) -> global___MediaEntry.ProgressiveJpegDetails: ...
    def __init__(
        self,
        *,
        fileSHA256: builtins.bytes | None = ...,
        mediaKey: builtins.bytes | None = ...,
        fileEncSHA256: builtins.bytes | None = ...,
        directPath: builtins.str | None = ...,
        mediaKeyTimestamp: builtins.int | None = ...,
        serverMediaType: builtins.str | None = ...,
        uploadToken: builtins.bytes | None = ...,
        validatedTimestamp: builtins.bytes | None = ...,
        sidecar: builtins.bytes | None = ...,
        objectID: builtins.str | None = ...,
        FBID: builtins.str | None = ...,
        downloadableThumbnail: global___MediaEntry.DownloadableThumbnail | None = ...,
        handle: builtins.str | None = ...,
        filename: builtins.str | None = ...,
        progressiveJPEGDetails: global___MediaEntry.ProgressiveJpegDetails | None = ...,
        size: builtins.int | None = ...,
        lastDownloadAttemptTimestamp: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["FBID", b"FBID", "directPath", b"directPath", "downloadableThumbnail", b"downloadableThumbnail", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "filename", b"filename", "handle", b"handle", "lastDownloadAttemptTimestamp", b"lastDownloadAttemptTimestamp", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp", "objectID", b"objectID", "progressiveJPEGDetails", b"progressiveJPEGDetails", "serverMediaType", b"serverMediaType", "sidecar", b"sidecar", "size", b"size", "uploadToken", b"uploadToken", "validatedTimestamp", b"validatedTimestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["FBID", b"FBID", "directPath", b"directPath", "downloadableThumbnail", b"downloadableThumbnail", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "filename", b"filename", "handle", b"handle", "lastDownloadAttemptTimestamp", b"lastDownloadAttemptTimestamp", "mediaKey", b"mediaKey", "mediaKeyTimestamp", b"mediaKeyTimestamp", "objectID", b"objectID", "progressiveJPEGDetails", b"progressiveJPEGDetails", "serverMediaType", b"serverMediaType", "sidecar", b"sidecar", "size", b"size", "uploadToken", b"uploadToken", "validatedTimestamp", b"validatedTimestamp"]) -> None: ...

global___MediaEntry = MediaEntry



from httpx import HTTPStatusError, ConnectTimeout
from linkpreview import Link, LinkPreview
from linkpreview import LinkGrabber as fallback_LinkGrabber
from linkpreview.exceptions import InvalidMimeTypeError
from .grabber import LinkGrabber


def fallback_grab_link(url: str):
    try:
        grabber = fallback_LinkGrabber(
            initial_timeout=20,
            maxsize=1048576,
            receive_timeout=10,
            chunk_size=1024,
        )
        return grabber.get_content(url, headers={"user-agent": "imessagebot", "accept": "*/*"})
    except Exception:
        return None, url


async def link_preview(
    url: str = None,
    content: str = None,
    parser: str = "html.parser",
):
    """
    Get link preview
    """
    if content is None:
        try:
            grabber = LinkGrabber()
            content, url = await grabber.get_content(url)
        except InvalidMimeTypeError:
            content = ""
        except ConnectTimeout:
            return False
        except HTTPStatusError:
            content, url = fallback_grab_link(url)
            if not content:
                return

    link = Link(url, content)
    return LinkPreview(link, parser=parser)
